﻿#!/usr/bin/python
# -*- coding=utf-8 -*-
"""
Constants used for stemming module
"""
import pyarabic.araby as ar
import re

VERB_LIST=()
def is_verb_stamp(stem):
    """
    Test if the stem can be found as verb stamp
    """
    return verb_stamp(stem) in VERB_LIST
        
def verb_stamp(verb):
    """
    create a hash as stamp to verbs
    """
    
    if not verb:
        return ""
    verb = ar.strip_tashkeel(verb)
    if not verb:
        return ""
    
    # if verb is  4 length
    # remove all
    if len(verb)==4 and verb.startswith(ar.ALEF_HAMZA_ABOVE):
        verb = verb.replace(ar.ALEF_HAMZA_ABOVE, '')
    # normalize hamza
    # Alef Madd will be converted into hamza + alef, the alef will be removed
    verb = re.sub(u'[أإءؤئآ]', u"ء", verb)
    # remove weak letters
    verb = re.sub(u'[اويى]', u"", verb)
    # remove double letter at the end
    if verb[-1:] == verb[-2:-1]:
        verb = verb[:-1]
    
    return verb
    
VERB_LIST =u"""آب
آتى
آتى
آثر
آثم
آجر
آجر
آخذ
آخذ
آخى
آد
آدب
آذن
آذى
آذى
آر
آر
آرق
آزر
آزف
آس
آسف
آسى
آض
آض
آق
آكد
آكل
آكل
آكل
آكل
آل
آلف
آلف
آلم
آلى
آم
آم
آمر
آمن
آن
آن
آنث
آنس
آنس
آنض
آنف
آنق
آه
آوى
أب
أب
أبأ
أبا
أبات
أباح
أباد
أبان
أبت
أبت
أبت
أبث
أبث
أبحر
أبد
أبد
أبد
أبدأ
أبدع
أبدل
أبدى
أبذأ
أبر
أبر
أبر
أبر
أبرأ
أبرح
أبرز
أبرق
أبرم
أبز
أبس
أبش
أبشر
أبشم
أبص
أبص
أبصر
أبض
أبض
أبض
أبط
أبطأ
أبطر
أبطل
أبعد
أبغض
أبغى
أبق
أبق
أبق
أبقى
أبك
أبكر
أبكى
أبل
أبل
أبل
أبل
أبل
أبلج
أبلغ
أبلى
أبن
أبن
أبه
أبه
أبهج
أبهر
أبهظ
أبهم
أبهى
أبى
أت
أتا
أتاح
أتبع
أتجر
أتحف
أتخم
أترح
أترع
أترف
أتعب
أتقن
أتكأ
أتل
أتلع
أتلف
أتم
أتم
أتم
أتمر
أتن
أتى
أث
أث
أث
أثأ
أثا
أثاب
أثار
أثبت
أثث
أثخن
أثر
أثر
أثر
أثر
أثر
أثر
أثرى
أثغر
أثف
أثف
أثقل
أثل
أثل
أثلث
أثلج
أثم
أثم
أثم
أثمر
أثمن
أثنى
أثى
أج
أج
أج
أج
أجأ
أجاب
أجاد
أجار
أجاز
أجاع
أجال
أجبر
أجج
أجحف
أجد
أجدب
أجدر
أجدى
أجذل
أجذم
أجر
أجر
أجر
أجر
أجر
أجرس
أجرم
أجرى
أجزل
أجزى
أجسد
أجفل
أجل
أجل
أجل
أجل
أجل
أجلب
أجلس
أجلى
أجم
أجم
أجم
أجمع
أجمل
أجن
أجن
أجن
أجن
أجن
أجنب
أجنح
أجهد
أجهر
أجهز
أجهش
أجهض
أجهم
أجود
أح
أحار
أحاط
أحاق
أحال
أحب
أحبس
أحبط
أحبك
أحبل
أحث
أحجم
أحد
أحد
أحدث
أحدق
أحرج
أحرز
أحرق
أحرم
أحزن
أحس
أحسن
أحصن
أحصى
أحضر
أحظى
أحق
أحقد
أحكم
أحل
أحلف
أحلى
أحمض
أحمى
أحن
أحن
أحنى
أحوج
أحيا
أخا
أخاف
أخال
أخبت
أخبث
أخبر
أخبى
أخثر
أخجل
أخدع
أخذ
أخذ
أخذ
أخذ
أخذ
أخذ
أخر
أخرج
أخرس
أخزى
أخصب
أخضب
أخضع
أخطأ
أخطر
أخف
أخفق
أخفى
أخل
أخلد
أخلص
أخلف
أخلى
أخمد
أخنع
أخنى
أخيل
أد
أد
أدأب
أدا
أدار
أدام
أدان
أدب
أدب
أدب
أدبر
أدجى
أدحض
أدخل
أدر
أدر
أدرج
أدرك
أدرى
أدسم
أدعث
أدعس
أدعص
أدعق
أدغم
أدفأ
أدكن
أدل
أدلج
أدلف
أدلى
أدم
أدم
أدم
أدم
أدمج
أدمع
أدمل
أدمن
أدمى
أدنأ
أدنى
أدهش
أدى
أدى
أذ
أذأب
أذاب
أذاع
أذاق
أذبل
أذج
أذعن
أذكى
أذل
أذن
أذن
أذن
أذنب
أذهب
أذهب
أذهل
أذي
أر
أر
أرا
أراب
أراث
أراح
أراد
أراع
أراق
أرب
أرب
أرب
أربذ
أربك
أربى
أرتع
أرج
أرج
أرجأ
أرجح
أرجع
أرجف
أرحب
أرخ
أرخ
أرخ
أرخف
أرخم
أرخى
أردأ
أردف
أردى
أرز
أرس
أرس
أرسب
أرسخ
أرسل
أرسن
أرسى
أرش
أرشح
أرشد
أرشف
أرشم
أرشى
أرصد
أرصع
أرض
أرض
أرض
أرض
أرض
أرضع
أرضى
أرط
أرط
أرطب
أرعب
أرعد
أرعش
أرعى
أرغد
أرغم
أرغى
أرفق
أرفل
أرفه
أرق
أرق
أرقد
أرقص
أرك
أرك
أرك
أرك
أركب
أركس
أركض
أركع
أركن
أرم
أرم
أرمد
أرمس
أرمش
أرمى
أرن
أرن
أرنق
أرهب
أرهف
أرهق
أروى
أري
أز
أز
أزأ
أزا
أزاح
أزاغ
أزاغ
أزال
أزال
أزب
أزب
أزبد
أزج
أزج
أزج
أزجى
أزح
أزحف
أزر
أزر
أزر
أزرى
أزعج
أزف
أزف
أزف
أزق
أزق
أزك
أزكى
أزل
أزل
أزلف
أزم
أزم
أزم
أزم
أزمع
أزمن
أزنى
أزهر
أزهق
أزهى
أزى
أزي
أس
أسا
أساء
أساغ
أسال
أسام
أسبح
أسبر
أسبع
أسبغ
أسبل
أسجى
أسخط
أسخن
أسخى
أسد
أسد
أسدر
أسدل
أسدى
أسر
أسر
أسر
أسرب
أسرج
أسرد
أسرع
أسرف
أسرى
أسس
أسعد
أسعف
أسف
أسفر
أسقط
أسقى
أسكت
أسكر
أسكن
أسل
أسلب
أسلح
أسلس
أسلف
أسلك
أسلم
أسمع
أسمل
أسمى
أسن
أسن
أسن
أسن
أسند
أسهب
أسهر
أسهل
أسهم
أسى
أسى
أش
أشاح
أشاد
أشار
أشاع
أشب
أشب
أشب
أشبع
أشبه
أشجى
أشح
أشحذ
أشد
أشر
أشر
أشر
أشر
أشرب
أشرح
أشرط
أشرع
أشرف
أشرق
أشرك
أشرى
أشع
أشعر
أشعل
أشغل
أشفق
أشفى
أشقى
أشكر
أشكل
أشل
أشمت
أشمس
أشنق
أشهد
أشهر
أشهى
أشى
أشي
أص
أص
أصا
أصاب
أصات
أصاخ
أصبح
أصبر
أصبغ
أصت
أصح
أصحب
أصحر
أصحى
أصد
أصد
أصد
أصدأ
أصدر
أصدق
أصر
أصر
أصعد
أصعق
أصغى
أصفق
أصفى
أصقع
أصل
أصل
أصل
أصل
أصلح
أصلد
أصلى
أصي
أض
أض
أضاء
أضاع
أضاف
أضجر
أضجع
أضحك
أضحى
أضرب
أضرم
أضعف
أضفى
أضل
أضم
أضمر
أضنك
أضنى
أط
أطاب
أطاح
أطار
أطاع
أطاف
أطاف
أطاق
أطال
أطبق
أطر
أطر
أطر
أطر
أطر
أطرب
أطرف
أطرق
أطرى
أطعم
أطغى
أطفأ
أطفح
أطل
أطلح
أطلع
أطلق
أطم
أطم
أطنب
أطول
أظرف
أظفر
أظل
أظلف
أظلم
أظمأ
أظهر
أعاد
أعاذ
أعار
أعاش
أعاق
أعال
أعان
أعتق
أعجب
أعجز
أعجف
أعجل
أعجم
أعد
أعدل
أعدم
أعذر
أعرب
أعرج
أعرض
أعرق
أعز
أعزب
أعسر
أعشب
أعشر
أعشى
أعصر
أعصف
أعصم
أعطب
أعطش
أعطى
أعظم
أعف
أعفن
أعفى
أعقب
أعقد
أعقل
أعقم
أعكر
أعلم
أعلن
أعلى
أعمد
أعمر
أعمق
أعمل
أعمى
أعن
أعند
أعنس
أعنف
أعنق
أعور
أعوز
أعوص
أعيا
أغاث
أغاث
أغار
أغار
أغاض
أغاظ
أغال
أغام
أغبر
أغبش
أغدق
أغرب
أغرد
أغرز
أغرس
أغرق
أغرم
أغرى
أغزر
أغزل
أغسق
أغشى
أغصن
أغضب
أغضن
أغضى
أغطش
أغفل
أغفى
أغل
أغلط
أغلظ
أغلق
أغلى
أغلى
أغم
أغمد
أغمض
أغمط
أغمى
أغن
أغنى
أغوى
أف
أف
أفاء
أفاح
أفاخ
أفاد
أفاض
أفاق
أفت
أفتق
أفتل
أفتى
أفج
أفجر
أفجع
أفحش
أفحم
أفخ
أفد
أفدى
أفر
أفر
أفرج
أفرح
أفرخ
أفرد
أفرز
أفرش
أفرط
أفرع
أفرغ
أفرك
أفرم
أفره
أفز
أفزع
أفسد
أفسل
أفشى
أفصح
أفضل
أفضى
أفطر
أفطم
أفظع
أفعم
أفف
أفق
أفق
أفقد
أفقر
أفقع
أفقه
أفك
أفك
أفكر
أفل
أفل
أفل
أفل
أفلت
أفلج
أفلح
أفلس
أفن
أفن
أفنى
أفهم
أقال
أقام
أقبح
أقبر
أقبس
أقبل
أقتر
أقتم
أقحم
أقدم
أقذع
أقذى
أقر
أقرأ
أقرب
أقرح
أقرس
أقرض
أقرع
أقرف
أقرن
أقسط
أقسم
أقسى
أقشع
أقصر
أقصى
أقض
أقط
أقطر
أقطع
أقعد
أقعر
أقعى
أقفر
أقفل
أقفى
أقلب
أقلع
أقلق
أقمح
أقمر
أقمع
أقنط
أقنع
أقول
أقوى
أقى
أك
أكأ
أكب
أكبح
أكبر
أكتب
أكثر
أكحل
أكد
أكد
أكدى
أكذب
أكر
أكرم
أكره
أكرى
أكسب
أكسد
أكسد
أكسد
أكسل
أكسى
أكشر
أكعب
أكفأ
أكفر
أكفل
أكل
أكل
أكل
أكل
أكل
أكلأ
أكلح
أكلف
أكم
أكمأ
أكمد
أكمش
أكمل
أكن
أكنف
أكى
أل
أل
أل
ألأم
ألا
ألاح
ألاذ
ألاع
ألام
ألان
ألب
ألب
ألب
ألب
ألب
ألب
ألب
ألبس
ألت
ألث
ألج
ألجأ
ألجم
ألح
ألحد
ألحف
ألحق
ألحم
ألحن
ألحى
ألد
ألز
ألز
ألز
ألزق
ألزم
ألس
ألسن
ألصق
ألطف
ألعب
ألعق
ألغز
ألغى
ألف
ألف
ألف
ألف
ألفى
ألق
ألقح
ألقم
ألقى
ألك
ألك
ألم
ألم
ألم
ألمح
ألمع
أله
أله
أله
ألهب
ألهج
ألهف
ألهم
ألهى
ألوى
ألي
أليل
ألين
أم
أم
أما
أمات
أماط
أمال
أمت
أمتع
أمثل
أمج
أمج
أمجد
أمح
أمحص
أمحض
أمخض
أمد
أمد
أمر
أمر
أمر
أمر
أمر
أمر
أمر
أمر
أمرض
أمرع
أمرغ
أمرق
أمس
أمسك
أمسى
أمشق
أمشى
أمص
أمصل
أمض
أمض
أمضغ
أمضى
أمطر
أمطى
أمعز
أمعن
أمكث
أمكر
أمكن
أمكن
أمل
أمل
أمل
أملح
أملس
أملط
أملق
أملك
أملى
أمم
أمن
أمن
أمن
أمن
أمنح
أمه
أمه
أمهر
أمهل
أمهى
أمو
أنأى
أناء
أناب
أناخ
أنار
أناط
أناف
أنال
أنام
أنب
أنبأ
أنبت
أنبط
أنت
أنتج
أنتن
أنث
أنث
أنجب
أنجح
أنجد
أنجر
أنجز
أنجس
أنجع
أنجف
أنجل
أنجم
أنجى
أنح
أنحف
أنحل
أنحى
أندب
أندر
أندف
أندم
أندى
أنذر
أنزر
أنزف
أنزق
أنزل
أنس
أنس
أنس
أنس
أنسف
أنسل
أنسى
أنشأ
أنشب
أنشد
أنشر
أنشط
أنشق
أنشل
أنصب
أنصت
أنصع
أنصف
أنصل
أنض
أنض
أنض
أنضج
أنضح
أنضر
أنضى
أنطف
أنطق
أنظر
أنظم
أنعت
أنعث
أنعس
أنعش
أنعل
أنعم
أنعى
أنغص
أنف
أنف
أنف
أنفد
أنفذ
أنفر
أنفس
أنفش
أنفض
أنفق
أنفل
أنق
أنق
أنق
أنقب
أنقح
أنقذ
أنقص
أنقض
أنقع
أنقل
أنقه
أنقى
أنك
أنكح
أنكد
أنكر
أنكف
أنكل
أنمر
أنمس
أنمى
أنه
أنهب
أنهج
أنهد
أنهر
أنهز
أنهض
أنهك
أنهل
أنهى
أنوأ
أنور
أنوى
أنى
أني
أه
أهاب
أهاج
أهان
أهب
أهب
أهبط
أهبل
أهجر
أهجم
أهدأ
أهدب
أهدر
أهدى
أهذب
أهذر
أهر
أهرأ
أهرب
أهرج
أهرع
أهرف
أهرق
أهرم
أهزل
أهضل
أهل
أهل
أهل
أهل
أهل
أهلك
أهلك
أهم
أهمأ
أهمد
أهمل
أهوج
أهوى
أهى
أهيق
أوب
أوب
أوبأ
أوبر
أوبق
أوتد
أوتر
أوثب
أوثف
أوثق
أوجب
أوجد
أوجز
أوجس
أوجع
أوجف
أوجل
أوجه
أوحج
أوحد
أوحش
أوحل
أوحى
أود
أود
أودع
أودى
أورث
أورد
أورس
أورط
أورع
أورف
أورق
أورم
أورى
أوزر
أوزع
أوزن
أوسخ
أوسط
أوسع
أوسق
أوشق
أوشك
أوشم
أوشى
أوصد
أوصف
أوصل
أوصى
أوضح
أوضخ
أوضع
أوضف
أوطأ
أوطن
أوعب
أوعد
أوعر
أوعز
أوعك
أوعى
أوغر
أوغل
أوفد
أوفر
أوفق
أوفى
أوقد
أوقر
أوقع
أوقف
أوكب
أوكد
أوكس
أوكل
أول
أول
أولج
أولد
أولع
أولى
أومأ
أومض
أونى
أوهب
أوهج
أوهم
أوهن
أوهى
أوى
أوى
أيأس
أيبس
أيتم
أيد
أيس
أيس
أيسر
أيفع
أيقظ
أيقن
أيك
أيم
أيمن
أينع
ائتام
ائتثر
ائتزر
ائتض
ائتكل
ائتلف
ائتلق
ائتلى
ائتمر
ائتمن
ابتأس
ابتاع
ابتدأ
ابتدع
ابتذل
ابتز
ابتسم
ابتعث
ابتعد
ابتغى
ابتكر
ابتل
ابتلع
ابتلى
ابتنى
ابتهج
ابتهل
ابيض
اتبع
اتجر
اتجه
اتحد
اتخذ
اتزر
اتزن
اتسخ
اتسع
اتسق
اتسم
اتشح
اتصف
اتصل
اتضح
اتعظ
اتفق
اتقد
اتقى
اتكأ
اتكل
اتكل
اتهم
اثاقل
اجتاح
اجتاز
اجتبى
اجتث
اجتذب
اجتر
اجترأ
اجترح
اجترع
اجترف
اجتز
اجتشأ
اجتلب
اجتمع
اجتنب
اجتنى
اجتهد
اجلوذ
اجلولى
احتاج
احتار
احتاط
احتال
احتبس
احتبى
احتج
احتجب
احتجز
احتد
احتدم
احتذى
احترز
احترس
احترف
احترق
احترم
احتسب
احتسى
احتشد
احتشم
احتضر
احتضن
احتطب
احتفظ
احتفل
احتفى
احتقر
احتقن
احتك
احتكر
احتكم
احتل
احتلب
احتلم
احتمل
احتمى
احتوى
احدودب
احلولك
احلولى
احمر
احور
احول
اختار
اختال
اختان
اختبأ
اختبر
اختبز
اختتم
اختتن
اخترع
اخترق
اختزل
اختزن
اختص
اختصر
اختصم
اختضب
اختط
اختط
اختطف
اختفى
اختل
اختلج
اختلس
اختلط
اختلف
اختلق
اختلى
اختمر
اختنق
اخشوشن
اخضر
اخضوضر
اخلولق
ادارأ
ادارك
ادثر
ادخر
ادعى
ادلهم
اذخر
اذكر
ارتأس
ارتأى
ارتاب
ارتاح
ارتاد
ارتاع
ارتبز
ارتبط
ارتبك
ارتبل
ارتج
ارتجف
ارتجل
ارتجى
ارتحل
ارتخى
ارتد
ارتدع
ارتدى
ارتزق
ارتسم
ارتشف
ارتشى
ارتصف
ارتضى
ارتطم
ارتعد
ارتعش
ارتفع
ارتقب
ارتقى
ارتكب
ارتكز
ارتكس
ارتكض
ارتمى
ارتهن
ارتوى
ارعوى
ارمد
ازداد
ازدان
ازدجر
ازدحم
ازدرد
ازدرى
ازدهر
ازدهى
ازدوج
ازرق
ازوار
ازور
استآس
استأب
استأثر
استأجر
استأخر
استأذن
استأسد
استأصل
استألف
استأمر
استأنس
استأنف
استأهل
استأوى
استاء
استباح
استبان
استبد
استبدل
استبرأ
استبرك
استبسل
استبشر
استبشع
استبصر
استبطأ
استبطن
استبعد
استبق
استبقى
استبهم
استتب
استتبع
استتر
استثار
استثار
استثقل
استثمر
استثنى
استجاب
استجار
استجد
استجدى
استجلب
استجلى
استجم
استجمع
استجمل
استجوب
استحال
استحال
استحب
استحث
استحدث
استحسر
استحسن
استحصد
استحصل
استحضر
استحفظ
استحق
استحقر
استحكم
استحل
استحلف
استحلى
استحم
استحمل
استحوذ
استحيا
استخبر
استخدم
استخرج
استخف
استخفى
استخلص
استخلف
استدار
استدام
استدان
استدبر
استدرج
استدرك
استدعى
استدفأ
استدفع
استدل
استذكر
استرأف
استراح
استرجع
استرخص
استرخى
استرد
استرزق
استرسل
استرشد
استرضع
استرضى
استرعى
استرق
استرهب
استروح
استزاد
استزل
استساغ
استسخر
استسقى
استسلم
استسمح
استسهل
استشار
استشاط
استشرف
استشرق
استشرى
استشعر
استشف
استشفع
استشفى
استشكل
استشهد
استصحب
استصدر
استصرخ
استصعب
استصغر
استصلح
استصوب
استضاء
استضاف
استضعف
استطاب
استطار
استطاع
استطال
استطرب
استطرد
استطرف
استطعم
استطلع
استطلق
استظرف
استظل
استظهر
استعاد
استعاذ
استعار
استعاض
استعان
استعبد
استعتب
استعجب
استعجل
استعجم
استعد
استعدى
استعذب
استعرب
استعرض
استعرف
استعصم
استعصى
استعطف
استعطى
استعظم
استعف
استعلم
استعلى
استعمر
استعمر
استعمل
استعيا
استغاث
استغرب
استغرق
استغشى
استغفر
استغفل
استغل
استغلظ
استغلق
استغلى
استغنى
استف
استفاد
استفاض
استفاق
استفتح
استفتى
استفحل
استفرد
استفرغ
استفره
استفز
استفسر
استفهم
استقال
استقام
استقبح
استقبل
استقدم
استقر
استقرأ
استقرى
استقسم
استقصى
استقطب
استقطع
استقل
استقى
استكان
استكبر
استكتب
استكثر
استكره
استكشف
استكمل
استل
استلب
استلذ
استلزم
استلطف
استلف
استلفت
استلقى
استلم
استلهم
استمات
استمال
استمتع
استمد
استمر
استمرأ
استمسك
استمع
استملح
استمهل
استناء
استنار
استنبأ
استنبط
استنتج
استنجد
استنجع
استنجى
استند
استنزف
استنزل
استنسخ
استنشد
استنشق
استنصر
استنطق
استنعش
استنفد
استنفذ
استنفر
استنقذ
استنكر
استنكف
استنهض
استهان
استهتر
استهجن
استهدف
استهدى
استهزأ
استهل
استهلك
استهول
استهوى
استوأى
استوثق
استوجب
استوحش
استوحى
استودع
استورد
استوصف
استوصى
استوضح
استوطن
استوعب
استوعد
استوعر
استوفد
استوفر
استوفى
استوقد
استوقف
استولد
استولى
استوى
استيأس
استيسر
استيقظ
استيقن
اسمر
اسواد
اسود
اشتاق
اشتبك
اشتبه
اشتد
اشترط
اشترع
اشترك
اشترى
اشتعل
اشتغل
اشتف
اشتق
اشتكى
اشتم
اشتمل
اشتهر
اشتهى
اشرأب
اشمأز
اشمخر
اصطاد
اصطاف
اصطب
اصطبر
اصطبغ
اصطحب
اصطخب
اصطدم
اصطرخ
اصطرع
اصطف
اصطفق
اصطفى
اصطك
اصطلح
اصطلى
اصطنع
اصفر
اضجع
اضطجع
اضطر
اضطرب
اضطرم
اضطلع
اضطهد
اضمحل
اطرد
اطلع
اطمأن
اطمأن
اطهر
اظلم
اعتاد
اعتاض
اعتبر
اعتبط
اعتجن
اعتد
اعتدل
اعتدى
اعتذر
اعترش
اعترض
اعترف
اعترك
اعترى
اعتز
اعتزل
اعتزم
اعتشب
اعتصب
اعتصر
اعتصم
اعتقد
اعتقل
اعتقم
اعتكف
اعتل
اعتلى
اعتمد
اعتمر
اعتنق
اعتنى
اعشوشب
اعوج
اعور
اعوز
اغبر
اغتاب
اغتاب
اغتار
اغتاظ
اغتال
اغتال
اغتبط
اغتذى
اغتر
اغترب
اغترف
اغتسل
اغتصب
اغتفر
اغتم
اغتمس
اغتنم
اغتنى
اغرورق
افتتح
افتتن
افتحص
افتخر
افتدى
افتر
افترس
افترش
افترض
افترق
افترى
افتصد
افتضح
افتعل
افتقد
افتقر
افتكر
افتل
افتن
اقتات
اقتاد
اقتبس
اقتتل
اقتحم
اقتدر
اقتدى
اقترب
اقترح
اقترض
اقترع
اقترف
اقترن
اقتسم
اقتص
اقتصد
اقتصر
اقتضب
اقتضى
اقتطع
اقتطف
اقتعد
اقتفى
اقتلع
اقتنص
اقتنع
اقتنى
اقشعر
اكتأب
اكتال
اكتتب
اكتتف
اكتتم
اكتحل
اكترث
اكترى
اكتسب
اكتسح
اكتسى
اكتشف
اكتظ
اكتفى
اكتلى
اكتمل
اكتنز
اكتنس
اكتنف
اكتنه
اكتهل
اكتوى
اكفهر
التأم
التأى
التاع
التبس
التبك
التجأ
التحف
التحق
التحم
التحى
التذ
التزق
التزم
التصق
التطم
التظى
التف
التفت
التقط
التقف
التقم
التقى
التكم
التمس
التهب
التهف
التهم
التهى
التوى
امتاح
امتاز
امتثل
امتحن
امتخض
امتخط
امتد
امتدح
امترس
امتزج
امتسك
امتشط
امتشق
امتص
امتطى
امتعض
امتقع
امتلأ
امتلك
امتن
امتنع
امتهن
امحق
امحى
انآد
انباع
انبت
انبث
انبثق
انبجس
انبرم
انبرى
انبسط
انبطح
انبعث
انبعج
انبغى
انبلج
انبنى
انبهت
انبهر
انتاب
انتبذ
انتبه
انتجع
انتجف
انتجى
انتحب
انتحر
انتحس
انتحل
انتحى
انتخب
انتدب
انتدى
انتزع
انتسب
انتسخ
انتسل
انتشر
انتشق
انتشل
انتشى
انتصب
انتصت
انتصح
انتصر
انتصف
انتضح
انتطح
انتظر
انتظم
انتعش
انتعل
انتفخ
انتفش
انتفض
انتفع
انتفل
انتفى
انتفى
انتقد
انتقش
انتقص
انتقض
انتقل
انتقم
انتقى
انتكس
انتكص
انتمى
انتهب
انتهج
انتهر
انتهز
انتهس
انتهض
انتهك
انتهى
انثال
انثقب
انثلم
انثنى
انجاب
انجال
انجبذ
انجبر
انجذب
انجذر
انجذم
انجر
انجرد
انجرف
انجزم
انجلب
انجلى
انجمع
انحاز
انحبس
انحت
انحجب
انحد
انحدر
انحذف
انحرف
انحسر
انحسم
انحصر
انحط
انحطم
انحقر
انحل
انحلب
انحمق
انحنى
انخدش
انخدع
انخذل
انخرب
انخرط
انخرق
انخرم
انخسف
انخفض
انخلع
انخنث
انخنق
اندبغ
اندثر
اندحر
اندرج
اندرس
اندس
اندفع
اندفق
اندفن
اندق
اندك
اندلس
اندلع
اندلف
اندلق
اندمج
اندمل
اندهش
انذعر
انذهل
انزاح
انزجر
انزرع
انزعج
انزعق
انزلج
انزلق
انزوى
انساب
انساب
انساق
انسبك
انستر
انسجم
انسحب
انسحق
انسد
انسدر
انسدل
انسرب
انسرح
انسرق
انسطح
انسفك
انسكب
انسل
انسلب
انسلت
انسلخ
انسلق
انسلك
انسلى
انشدخ
انشرح
انشطر
انشعب
انشغف
انشغل
انشق
انشل
انشمر
انشوى
انصاب
انصات
انصاح
انصاع
انصب
انصدع
انصرح
انصرع
انصرف
انصرم
انصعق
انصفق
انصقل
انصلح
انصهر
انضاج
انضاف
انضبط
انضخ
انضرج
انضغط
انضفر
انضم
انضمخ
انضمر
انضوى
انطاد
انطار
انطاع
انطبخ
انطبع
انطبق
انطرح
انطفأ
انطلق
انطلى
انطمس
انطوى
انظلم
انعتق
انعجم
انعدل
انعدم
انعرج
انعزل
انعصب
انعصر
انعصم
انعطف
انعفر
انعفق
انعقد
انعقف
انعكس
انغاض
انغرز
انغرس
انغسل
انغض
انغضف
انغط
انغلق
انغم
انغمر
انغمس
انغمض
انفتح
انفتق
انفتل
انفث
انفجر
انفرج
انفرد
انفرط
انفرق
انفرك
انفسح
انفسخ
انفش
انفصد
انفصل
انفصم
انفض
انفضح
انفطر
انفطم
انفعل
انفغر
انفقأ
انفقص
انفقع
انفك
انفل
انفلت
انفلج
انفلق
انقاد
انقاس
انقاض
انقاض
انقبض
انقبع
انقذف
انقرض
انقسم
انقشر
انقشع
انقص
انقصف
انقصم
انقض
انقضى
انقطع
انقعر
انقفل
انقلب
انقلع
انكب
انكبت
انكبس
انكتب
انكتم
انكثب
انكدر
انكسر
انكسف
انكشف
انكف
انكفأ
انكمش
انمحق
انمحى
انمس
انهار
انهال
انهبط
انهتك
انهجم
انهد
انهدم
انهزم
انهشم
انهضم
انهل
انهلك
انهمر
انهمز
انهمك
انهوى
اهتاج
اهتبل
اهتدى
اهترأ
اهتز
اهتزع
اهتل
اهتلك
اهتم
اهرورق
ايراق
بآ
بأبأ
بأج
بأر
بأش
بأه
بأى
بؤس
بؤل
بئس
باب
باب
بات
بات
باث
باث
باج
باح
باحث
باخ
باد
بادأ
بادر
بادل
بادى
باذ
بارح
بارز
بارك
بارى
باز
باز
باس
باسط
باش
باشر
باص
باصر
باط
باطأ
باظ
باظ
باع
باعد
باغ
باغت
باق
باك
باكر
بال
بالغ
بالى
باه
باه
باهت
باهر
باهى
بايع
بت
بت
بتأ
بتا
بتر
بتر
بتع
بتع
بتع
بتك
بتك
بتل
بتل
بتل
بث
بث
بثا
بثر
بثر
بثر
بثط
بثع
بثق
بج
بج
بجح
بجح
بجد
بجر
بجر
بجس
بجس
بجع
بجل
بجل
بجل
بجل
بجم
بح
بح
بحت
بحث
بحر
بحر
بحز
بحش
بخ
بخا
بخت
بخر
بخر
بخر
بخر
بخز
بخس
بخص
بخص
بخع
بخع
بخق
بخق
بخل
بخل
بخن
بد
بد
بدأ
بدا
بدح
بدخ
بدد
بدر
بدس
بدع
بدع
بدع
بدغ
بدغ
بدل
بدل
بدل
بدل
بدن
بدن
بدن
بده
بدي
بذ
بذ
بذأ
بذؤ
بذئ
بذا
بذح
بذح
بذخ
بذخ
بذخ
بذر
بذر
بذر
بذع
بذل
بذل
بذم
بذو
بر
بر
برأ
برأ
برؤ
برئ
برئ
برا
بربر
برت
برث
برج
برج
برح
برح
برح
برد
برد
برد
برذن
برر
برز
برز
برز
برز
برس
برش
برشم
برص
برص
برض
برض
برطل
برع
برع
برع
برعم
برغ
برق
برقش
برك
برم
برم
برمج
بره
برهن
بروز
برى
بز
بزا
بزبز
بزج
بزخ
بزخ
بزر
بزع
بزل
بزم
بزم
بزي
بس
بسأ
بسئ
بستر
بسر
بسط
بسط
بسط
بسق
بسل
بسم
بسمل
بش
بشا
بشر
بشر
بشر
بشر
بشع
بشق
بشك
بشك
بشم
بص
بصا
بصبص
بصر
بصر
بصر
بصر
بصع
بصق
بصم
بض
بض
بضع
بضع
بضك
بضم
بط
بطأ
بطؤ
بطبط
بطح
بطر
بطر
بطر
بطش
بطش
بطغ
بطل
بطل
بطل
بطن
بطن
بطن
بطن
بظ
بظا
بظر
بع
بع
بعا
بعا
بعث
بعث
بعثر
بعج
بعد
بعد
بعد
بعر
بعص
بعض
بعط
بعق
بعك
بعك
بعل
بعل
بعى
بغ
بغت
بغث
بغر
بغر
بغر
بغز
بغش
بغض
بغض
بغض
بغض
بغل
بغم
بغم
بغم
بغى
بق
بق
بقا
بقبق
بقت
بقث
بقر
بقر
بقط
بقع
بقع
بقع
بقل
بقم
بقى
بقى
بقي
بك
بكأ
بكؤ
بكئ
بكت
بكر
بكر
بكر
بكس
بكش
بكع
بكل
بكم
بكم
بكم
بكى
بل
بلا
بلبل
بلت
بلت
بلت
بلت
بلج
بلج
بلح
بلخ
بلد
بلد
بلد
بلسم
بلط
بلط
بلع
بلع
بلعم
بلغ
بلغ
بلغ
بلق
بلق
بلق
بلك
بلل
بلم
بله
بلور
بلي
بن
بنج
بنج
بنح
بنش
بنق
بنى
به
بهأ
بهؤ
بهئ
بها
بها
بهت
بهت
بهت
بهث
بهج
بهج
بهج
بهدل
بهر
بهرج
بهز
بهس
بهش
بهص
بهض
بهظ
بهق
بهل
بهل
بهو
بهي
بوأ
بوب
بور
بوق
بول
بوه
بوى
بيت
بيت
بيض
بيطر
بيطر
بين
تآخى
تآزر
تآكل
تآلف
تآمر
تآنس
تأبد
تأبط
تأتأ
تأتى
تأثث
تأثر
تأثم
تأجج
تأجل
تأخر
تأخى
تأدب
تأذن
تأر
تأرجح
تأز
تأزم
تأسد
تأسس
تأسف
تأسى
تأصل
تأطر
تأفف
تأقلم
تأكد
تأكسد
تأكل
تألب
تألف
تألق
تألم
تأله
تأمر
تأمرك
تأمل
تأمم
تأنث
تأنس
تأنق
تأنى
تأهب
تأهل
تأول
تأوه
تأى
تأيد
تئق
تاءم
تاب
تابع
تاج
تاجر
تاح
تاح
تاخ
تاخم
تار
تاز
تاز
تاس
تاع
تاع
تاف
تاك
تال
تام
تاه
تب
تبا
تباجح
تباحث
تبادر
تبادل
تبارز
تبارك
تبارى
تباشر
تباطأ
تباعد
تباغض
تباكى
تباهى
تبايع
تباين
تبتل
تبجح
تبحر
تبختر
تبخر
تبدد
تبدل
تبدى
تبر
تبر
تبر
تبر
تبرأ
تبرج
تبرجز
تبرد
تبرر
تبرز
تبرطل
تبرع
تبرعم
تبرك
تبرم
تبسط
تبسم
تبصر
تبضع
تبطأ
تبع
تبعثر
تبغدد
تبقى
تبل
تبلبل
تبلج
تبلد
تبلع
تبلغ
تبلل
تبله
تبلور
تبن
تبن
تبنى
تبهج
تبهر
تبهرج
تبوأ
تبول
تبيض
تبيطر
تبين
تتابع
تتالع
تتالى
تتبع
تترب
تتلمذ
تتوج
تتوق
تثاءب
تثاقف
تثاقل
تثبت
تثعلب
تثقب
تثقف
تثلج
تثلم
تثمل
تثنى
تجادل
تجاذب
تجاسر
تجافى
تجالد
تجالس
تجانب
تجانس
تجاهر
تجاهل
تجاوب
تجاور
تجاور
تجاوز
تجبر
تجبن
تجدد
تجذف
تجر
تجرأ
تجرد
تجرع
تجزأ
تجسد
تجسس
تجسم
تجشأ
تجشم
تجعد
تجفف
تجلبب
تجلد
تجلط
تجلل
تجلى
تجمد
تجمع
تجمل
تجمهر
تجنب
تجند
تجنس
تجنن
تجنى
تجهز
تجهم
تجود
تجورب
تجوز
تجوع
تجوف
تجول
تجيش
تحاب
تحات
تحاث
تحاج
تحاجى
تحادب
تحادث
تحاذى
تحارب
تحارض
تحازن
تحاسب
تحاسد
تحاشد
تحاشى
تحاقد
تحاقر
تحاك
تحاكم
تحالف
تحامق
تحامل
تحامى
تحاور
تحايل
تحبب
تحبر
تحتم
تحجب
تحجج
تحجر
تحدب
تحدث
تحدد
تحدر
تحدى
تحذق
تحذلق
تحرج
تحرر
تحرز
تحرش
تحرق
تحرك
تحرى
تحزب
تحزم
تحسب
تحسر
تحسس
تحسن
تحسى
تحشد
تحصل
تحصن
تحضر
تحطم
تحفز
تحفظ
تحقق
تحكم
تحلب
تحلحل
تحلق
تحلل
تحلى
تحم
تحمس
تحمل
تحمم
تحنث
تحنى
تحوز
تحول
تحيا
تحير
تحيز
تحيز
تحين
تخ
تخابث
تخابر
تخاتل
تخادع
تخاذل
تخاصم
تخاطأ
تخاطب
تخاطر
تخافت
تخالص
تخالط
تخالف
تخايل
تخبأ
تخبر
تخبط
تخثر
تخذ
تخرج
تخرق
تخرم
تخشب
تخشع
تخشن
تخصص
تخضب
تخطأ
تخطف
تخطى
تخفف
تخفى
تخلخل
تخلص
تخلف
تخلق
تخلل
تخلى
تخم
تخمر
تخنث
تخندق
تخوف
تخير
تخيل
تخيم
تداخل
تدارس
تدارك
تداعب
تداعى
تدافع
تداول
تداوى
تداين
تدبر
تدثر
تدجج
تدحرج
تدخل
تدخن
تدرب
تدرج
تدرع
تدروش
تدسس
تدعدع
تدعم
تدفأ
تدفق
تدلك
تدلل
تدله
تدلى
تدنأ
تدنس
تدنى
تدهن
تدهور
تدين
تذاءب
تذاكر
تذبذب
تذرع
تذكر
تذلل
تذمر
تذوق
تر
تر
تر
ترأس
ترأف
ترأم
ترأى
تراءى
ترابط
تراجع
تراحم
تراخى
ترادف
تراسل
تراشق
تراص
تراصد
تراصف
تراضى
تراغب
ترافع
ترافق
تراقب
تراقص
تراقى
تراكض
تراكل
تراكم
ترامى
تراهن
تراوح
تراوغ
ترب
ترب
تربص
تربع
تربل
تربى
ترتب
ترج
ترج
ترجح
ترجع
ترجف
ترجل
ترجم
ترجى
ترح
ترح
ترحم
ترخ
تردد
تردى
ترز
ترز
ترزن
ترس
ترسب
ترسخ
ترسل
ترسم
ترش
ترشح
ترشش
ترشف
ترص
ترصد
ترصع
ترصف
ترضى
ترطب
ترع
ترع
ترعبل
ترعرع
ترف
ترف
ترفع
ترفق
ترفل
ترفه
ترقب
ترقرق
ترقع
ترقق
ترقى
ترك
ترك
تركب
تركز
تركل
تركن
ترمرم
ترمل
ترمم
ترنح
ترنق
ترنم
تره
ترهب
ترهل
تروح
تروض
تروع
ترول
تروى
ترى
تريث
تريض
تزاحف
تزاحم
تزامن
تزاهد
تزاهر
تزاوج
تزاور
تزايد
تزبب
تزحزح
تزحلق
تزخرف
تزعزع
تزعم
تزكى
تزلج
تزلزل
تزلف
تزمت
تزمخر
تزمزم
تزمل
تزندق
تزهد
تزوج
تزود
تزيا
تزين
تساءل
تساب
تسابق
تساجل
تسار
تسارع
تسافد
تساقط
تساقى
تساكب
تساكن
تسالم
تسامح
تسامر
تسامع
تسامى
تساهل
تساوم
تساوى
تساير
تسايف
تسايل
تسبب
تستر
تسجل
تسخر
تسدد
تسدر
تسرب
تسربل
تسرح
تسرع
تسرول
تسطح
تسع
تسع
تسعر
تسفد
تسفر
تسفل
تسفه
تسقط
تسكع
تسكن
تسلح
تسلخ
تسلسل
تسلط
تسلطن
تسلف
تسلق
تسلل
تسلم
تسلى
تسمر
تسمع
تسمم
تسمى
تسنم
تسنن
تسنى
تسهد
تسهل
تسور
تسوس
تسوق
تسول
تسول
تسوى
تسيطر
تشاءم
تشاءى
تشابك
تشابه
تشاتم
تشاجر
تشاح
تشاحن
تشاد
تشارس
تشارط
تشارك
تشازر
تشاغب
تشاغل
تشاكس
تشاكل
تشاكى
تشامخ
تشانق
تشاور
تشايخ
تشايع
تشبب
تشبث
تشبع
تشبك
تشبه
تشتت
تشجع
تشخص
تشدد
تشدق
تشذب
تشرد
تشرذم
تشرف
تشظى
تشعب
تشعث
تشعشع
تشعل
تشفع
تشفى
تشقق
تشكر
تشكك
تشكل
تشكى
تشلشل
تشمت
تشمر
تشمس
تشمم
تشنج
تشنن
تشهد
تشهى
تشوش
تشوف
تشوق
تشوه
تشيطن
تشيطن
تشيع
تصابى
تصاحب
تصاخب
تصادف
تصادق
تصادم
تصارخ
تصارع
تصاعب
تصاعد
تصاغر
تصاف
تصافح
تصافع
تصافى
تصالح
تصاهر
تصاهل
تصاول
تصايح
تصبب
تصبح
تصبر
تصبن
تصحح
تصدر
تصدع
تصدق
تصدى
تصرف
تصرم
تصعب
تصعلك
تصفح
تصلب
تصنع
تصنف
تصور
تصوف
تصون
تصيد
تصيف
تضاءل
تضاجع
تضاحك
تضاد
تضارب
تضاعف
تضاغط
تضاغن
تضافر
تضام
تضامن
تضايق
تضجر
تضخم
تضرج
تضرر
تضرع
تضرم
تضعضع
تضلع
تضمخ
تضمد
تضمر
تضمن
تضوأ
تضور
تضوع
تضيق
تطأطأ
تطأمن
تطا
تطابق
تطاحن
تطارح
تطارد
تطاعن
تطاوع
تطاول
تطاير
تطبب
تطبع
تطبق
تطرب
تطرز
تطرف
تطرق
تطفل
تطلب
تطلع
تطهر
تطور
تطوس
تطوع
تطوف
تطول
تطيب
تطير
تطيف
تظافر
تظاهر
تظلل
تظلم
تع
تع
تعادل
تعادى
تعارض
تعارف
تعارك
تعازل
تعازى
تعاسر
تعاشر
تعاض
تعاضد
تعاطف
تعاطى
تعاظل
تعاظم
تعافى
تعاقب
تعاقد
تعاكس
تعالج
تعالم
تعالى
تعالى
تعامل
تعامى
تعاند
تعانق
تعاهد
تعاور
تعاون
تعايب
تعاير
تعايش
تعب
تعبد
تعبس
تعتع
تعثر
تعجب
تعجرف
تعجل
تعجن
تعدد
تعدد
تعدى
تعذب
تعذر
تعر
تعرب
تعرج
تعرض
تعرف
تعرق
تعرقل
تعرى
تعزب
تعزز
تعس
تعس
تعسر
تعسف
تعشق
تعشى
تعص
تعصب
تعصر
تعصى
تعطر
تعطش
تعطف
تعطل
تعظل
تعظم
تعفر
تعفرت
تعفف
تعفن
تعقب
تعقد
تعقل
تعكز
تعل
تعلف
تعلق
تعلل
تعلم
تعلى
تعمج
تعمد
تعمق
تعمم
تعنى
تعهد
تعوج
تعود
تعوذ
تعوض
تعوق
تعى
تعيش
تعين
تغا
تغابط
تغابن
تغابى
تغازل
تغاضى
تغافل
تغالب
تغالط
تغامز
تغامس
تغامض
تغانى
تغاور
تغاوى
تغايب
تغاير
تغب
تغب
تغدى
تغذى
تغر
تغر
تغرب
تغرد
تغرغر
تغزل
تغشم
تغشى
تغضب
تغضن
تغطرس
تغطرف
تغطى
تغفل
تغلب
تغلغل
تغلف
تغمد
تغمغم
تغنج
تغنم
تغنى
تغور
تغوط
تغى
تغيب
تغير
تغيظ
تغيل
تغيم
تف
تفئ
تفاءل
تفاتح
تفاجر
تفاحش
تفاخر
تفادى
تفارق
تفاسح
تفاسخ
تفاسد
تفاصح
تفاضح
تفاضل
تفاعل
تفاقد
تفاقم
تفاكه
تفانى
تفاهم
تفاوت
تفاوض
تفاوه
تفتت
تفتح
تفتر
تفتق
تفتك
تفتل
تفث
تفجر
تفجع
تفحش
تفحص
تفخر
تفرج
تفرد
تفرس
تفرع
تفرعن
تفرغ
تفرق
تفرقع
تفرنج
تفرنس
تفزر
تفسح
تفسخ
تفسر
تفشى
تفصح
تفصد
تفصل
تفضل
تفضى
تفطر
تفطن
تفقأ
تفقد
تفقص
تفقفق
تفقم
تفقه
تفكر
تفكك
تفكه
تفل
تفل
تفل
تفلت
تفلج
تفلح
تفلسف
تفلق
تفلى
تفن
تفنن
تفه
تفه
تفهم
تفوق
تفوه
تفيأ
تفيش
تقابل
تقاتل
تقادم
تقاذف
تقارب
تقارص
تقارض
تقارظ
تقارع
تقارن
تقاسم
تقاصر
تقاصف
تقاضى
تقاطر
تقاطع
تقاعد
تقاعس
تقافز
تقالد
تقامر
تقاول
تقاوم
تقاوى
تقايض
تقايل
تقبب
تقبض
تقبل
تقحم
تقدد
تقدر
تقدس
تقدم
تقذر
تقرب
تقرح
تقرر
تقرفص
تقزز
تقزم
تقسم
تقشر
تقشط
تقشع
تقشف
تقصد
تقصص
تقصف
تقصى
تقضب
تقضى
تقطر
تقطع
تقع
تقعد
تقعر
تقفى
تقلب
تقلد
تقلص
تقلع
تقلقل
تقلى
تقمص
تقمم
تقنص
تقنع
تقهقر
تقوت
تقوس
تقوض
تقوقع
تقول
تقوم
تقوى
تقيأ
تقيح
تقيد
تقيض
تقيف
تقيل
تقين
تك
تك
تكأكأ
تكابر
تكاتب
تكاتف
تكاتم
تكاثر
تكاثف
تكاذب
تكاره
تكاسل
تكاشف
تكافأ
تكافح
تكافل
تكالب
تكامل
تكايد
تكايل
تكبد
تكبر
تكبس
تكتف
تكتك
تكتكت
تكتل
تكثر
تكثم
تكحل
تكدر
تكدس
تكذب
تكربع
تكرر
تكرس
تكرش
تكركر
تكرم
تكره
تكسب
تكسر
تكسى
تكشر
تكشف
تكعب
تكفف
تكفكف
تكفل
تكفن
تكلس
تكلف
تكلل
تكلم
تكمأ
تكمكم
تكمل
تكمم
تكنس
تكنف
تكنى
تكهرب
تكهف
تكهن
تكوثر
تكور
تكون
تكيس
تكيف
تل
تلألأ
تلا
تلا
تلاءم
تلاثم
تلاحظ
تلاحق
تلاحم
تلاحى
تلاذ
تلاشى
تلاصق
تلاطف
تلاطم
تلاعب
تلاعن
تلافى
تلاقى
تلاكز
تلاكم
تلاكن
تلاهى
تلاوم
تلاوى
تلبب
تلبث
تلبد
تلبس
تلبك
تلبنن
تلثم
تلجج
تلجلج
تلجن
تلحح
تلحف
تلخص
تلد
تلد
تلد
تلدن
تلذذ
تلذع
تلزج
تلصص
تلطخ
تلطف
تلطم
تلظى
تلع
تلع
تلع
تلعثم
تلعلع
تلغم
تلف
تلفت
تلفز
تلفز
تلفظ
تلفف
تلفلف
تلفن
تلفن
تلقب
تلقح
تلقط
تلقف
تلقم
تلقن
تلقى
تلكأ
تلمج
تلمذ
تلمذ
تلمس
تلمع
تلمق
تلملم
تله
تلهب
تلهف
تلهى
تلوث
تلوح
تلوم
تلون
تلوه
تلوى
تلى
تلى
تلي
تليث
تلين
تم
تماثل
تماجد
تمادى
تمارس
تمارض
تمارى
تمازج
تمازح
تماس
تماسك
تماسى
تماشق
تماشى
تماكر
تماكس
تمالك
تماوت
تماوج
تمايد
تمايز
تمايل
تمتع
تمتم
تمثل
تمجد
تمجن
تمحص
تمحور
تمخض
تمخط
تمدد
تمدرس
تمدن
تمدين
تمذهب
تمر
تمر
تمر
تمرأ
تمرد
تمرس
تمرع
تمرغ
تمرفق
تمركز
تمرمر
تمرن
تمزق
تمسح
تمسك
تمسكن
تمسلم
تمش
تمشى
تمصر
تمضمض
تمضى
تمطر
تمطط
تمطق
تمطى
تمظهر
تمعن
تمغرب
تمغص
تمفصل
تمقت
تمك
تمك
تمكث
تمكن
تملأ
تملس
تملص
تملق
تملك
تململ
تملى
تمم
تمندل
تمنطق
تمنع
تمنن
تمنى
تمه
تمهد
تمهر
تمهل
تموج
تمور
تمول
تمون
تموه
تميد
تميز
تميس
تميع
تميل
تن
تنأ
تناءى
تنابذ
تنابز
تنابل
تناتف
تناثر
تناجى
تناحر
تناحس
تناد
تنادم
تنادى
تنازع
تنازل
تناسب
تناسخ
تناسق
تناسل
تناسى
تناشد
تناص
تناصب
تناصح
تناصر
تناصف
تناصى
تناضل
تناطح
تناظر
تناظم
تناعت
تناعس
تناعم
تناعى
تناغم
تناغى
تنافر
تنافس
تنافى
تناقش
تناقص
تناقض
تناقل
تناكح
تناكر
تنامى
تناهب
تناهد
تناهش
تناهض
تناهى
تناوب
تناول
تناوم
تنبأ
تنبل
تنبه
تنتف
تنثر
تنجح
تنجد
تنجز
تنجس
تنجع
تنجم
تنحل
تنحنح
تنحى
تنخ
تنخ
تندم
تندى
تنزل
تنزه
تنسب
تنسق
تنسك
تنسم
تنشأ
تنشب
تنشد
تنشر
تنشط
تنشف
تنشق
تنصب
تنصت
تنصح
تنصر
تنصف
تنصل
تنصى
تنضح
تنضد
تنطع
تنطق
تنظر
تنظف
تنظم
تنعت
تنعل
تنعم
تنغص
تنغم
تنفس
تنفش
تنفط
تنفل
تنقب
تنقد
تنقذ
تنقص
تنقض
تنقل
تنقى
تنكب
تنكد
تنكر
تنكس
تنم
تنمر
تنمل
تنهد
تنور
تنوع
تنول
تنوم
تنوى
تها
تهاتر
تهاجر
تهاجم
تهاجى
تهاد
تهادن
تهادى
تهارب
تهارت
تهارش
تهارق
تهارم
تهاطل
تهافت
تهالك
تهامس
تهامش
تهاون
تهاوى
تهايج
تهتك
تهجد
تهجر
تهجم
تهجى
تهدب
تهدج
تهدد
تهدل
تهدم
تهدهد
تهذب
تهرأ
تهرب
تهرطق
تهزأ
تهزج
تهزز
تهزع
تهزم
تهزهز
تهشم
تهطل
تهفهف
تهكم
تهلل
تهلهل
تهلوس
تهم
تهن
تهنأ
تهوج
تهود
تهور
تهوس
تهوش
تهوم
تهيأ
تهيب
تهيج
تهيم
تواءم
تواتر
تواثب
تواجد
تواجه
تواد
توادع
توارث
توارد
توارى
توازن
توازى
تواصف
تواصل
تواصى
تواضع
تواطأ
تواعد
توافد
توافر
توافق
تواقح
تواقف
تواكب
تواكل
توالد
توالى
توانى
تواهب
توتر
توثب
توثق
توج
توجب
توجد
توجس
توجع
توجه
توحد
توحش
توحل
توحم
توخى
تودد
تودع
تورد
تورط
تورع
تورع
تورك
تورم
توزر
توزع
توسخ
توسد
توسط
توسع
توسل
توسم
توسن
توشح
توشوش
توشى
توصل
توضأ
توضح
توطأ
توطد
توطن
توظف
توعد
توعر
توعك
توغر
توغل
توفر
توفق
توفى
توقح
توقد
توقر
توقع
توقف
توقى
توكأ
توكد
توكل
تولج
تولد
تولع
توله
تولول
تولى
توه
توهج
توهد
توهم
توهن
توى
توي
تياسر
تيامن
تيتم
تيس
تيسر
تيفع
تيقظ
تيقن
تيم
تيمم
تيمن
تيه
ثأج
ثأر
ثأى
ثئب
ثئد
ثئط
ثئي
ثاب
ثابر
ثاخ
ثار
ثاع
ثاع
ثاقف
ثال
ثامن
ثب
ثبت
ثبت
ثبت
ثبج
ثبج
ثبج
ثبر
ثبر
ثبط
ثبط
ثبط
ثبق
ثبن
ثبى
ثتم
ثتن
ثج
ثج
ثجا
ثجر
ثجر
ثجل
ثجم
ثجم
ثحج
ثخ
ثخن
ثدا
ثدغ
ثدق
ثدن
ثدى
ثدي
ثر
ثر
ثرا
ثرب
ثرب
ثرثر
ثرد
ثرد
ثرط
ثرع
ثرغ
ثرم
ثرم
ثرن
ثرى
ثري
ثط
ثط
ثطأ
ثطئ
ثطا
ثطع
ثطي
ثع
ثعب
ثعر
ثعط
ثعل
ثعم
ثغا
ثغب
ثغر
ثغم
ثفأ
ثفا
ثفج
ثفر
ثفل
ثفن
ثفن
ثفى
ثقب
ثقب
ثقب
ثقف
ثقف
ثقف
ثقف
ثقل
ثقل
ثقل
ثقل
ثك
ثكل
ثكم
ثكم
ثل
ثل
ثلب
ثلب
ثلث
ثلث
ثلث
ثلج
ثلج
ثلج
ثلج
ثلخ
ثلخ
ثلد
ثلط
ثلع
ثلغ
ثلم
ثلم
ثم
ثمأ
ثمج
ثمد
ثمد
ثمد
ثمر
ثمر
ثمغ
ثمل
ثمن
ثمن
ثمن
ثمن
ثنت
ثنط
ثنى
ثنى
ثها
ثهت
ثوب
ثور
ثول
ثيب
جآ
جأب
جأث
جأج
جأذ
جأر
جأش
جأص
جأف
جأل
جأى
جئث
جئر
جئز
جئل
جئي
جاء
جاب
جاب
جابل
جابه
جاثى
جاج
جاح
جاخ
جاخ
جاد
جاد
جادل
جاذب
جار
جار
جارى
جاز
جازف
جازى
جاس
جاش
جاش
جاض
جاظ
جاظ
جاع
جاف
جاف
جافى
جالد
جالس
جام
جامع
جامل
جان
جانب
جانس
جانى
جاه
جاهد
جاهر
جاهل
جاوب
جاود
جاور
جاوز
جب
جبأ
جبئ
جبا
جبج
جبح
جبخ
جبذ
جبر
جبر
جبز
جبز
جبس
جبش
جبل
جبل
جبل
جبن
جبن
جبن
جبه
جبه
جبى
جبى
جت
جث
جث
جثا
جثط
جثل
جثل
جثل
جثى
جح
جحا
جحد
جحد
جحر
جحس
جحش
جحظ
جحف
جحل
جحم
جحم
جحم
جحن
جحن
جخ
جخا
جخر
جخر
جخف
جخف
جخف
جد
جدا
جدب
جدب
جدب
جدب
جدح
جدد
جدر
جدر
جدر
جدر
جدس
جدش
جدع
جدع
جدع
جدف
جدف
جدل
جدل
جدل
جدل
جدم
جدول
جدى
جذ
جذا
جذب
جذب
جذر
جذر
جذع
جذف
جذف
جذل
جذل
جذم
جذم
جذم
جذى
جر
جرأ
جرؤ
جرب
جرب
جرج
جرج
جرجر
جرح
جرح
جرح
جرد
جرد
جرد
جرذ
جرذ
جرذ
جرر
جرز
جرز
جرز
جرس
جرس
جرس
جرش
جرش
جرش
جرض
جرض
جرض
جرط
جرع
جرع
جرع
جرف
جرف
جرل
جرم
جرم
جرم
جرم
جرم
جرن
جرى
جرى
جز
جز
جزأ
جزأ
جزئ
جزح
جزر
جزر
جزز
جزع
جزع
جزع
جزف
جزل
جزل
جزل
جزم
جزى
جس
جسأ
جسا
جسد
جسد
جسر
جسع
جسم
جسم
جسي
جش
جش
جشأ
جشأ
جشب
جشب
جشب
جشر
جشر
جشع
جشم
جشم
جشن
جص
جصص
جض
جظ
جع
جعا
جعب
جعب
جعجع
جعد
جعد
جعر
جعس
جعظ
جعظ
جعف
جعل
جعل
جعم
جعم
جف
جف
جف
جفأ
جفا
جفخ
جفخ
جفر
جفر
جفس
جفش
جفظ
جفع
جفف
جفل
جفل
جفل
جفن
جفى
جق
جلأ
جلا
جلب
جلب
جلب
جلب
جلبب
جلت
جلجل
جلح
جلح
جلخ
جلد
جلد
جلد
جلد
جلز
جلس
جلط
جلع
جلع
جلغ
جلف
جلف
جلق
جلل
جلم
جله
جله
جلى
جلى
جلي
جم
جمئ
جمجم
جمخ
جمد
جمد
جمد
جمر
جمر
جمس
جمس
جمش
جمش
جمع
جمع
جمل
جمل
جمل
جمم
جمهر
جمى
جن
جنأ
جنئ
جنب
جنب
جنب
جنب
جنب
جنح
جنح
جنح
جنح
جند
جندل
جنز
جنس
جنس
جنش
جنف
جنف
جنق
جنن
جنى
جه
جهث
جهد
جهد
جهر
جهر
جهر
جهز
جهز
جهش
جهش
جهض
جهل
جهل
جهم
جهم
جهم
جهن
جهور
جهي
جوب
جوث
جود
جورب
جوز
جوع
جوف
جوف
جوق
جوق
جول
جول
جون
جوي
جيب
جيد
جير
جير
جيش
جيف
حاب
حاب
حابس
حابى
حات
حاث
حاج
حاج
حاجى
حاد
حاد
حاد
حادث
حاذ
حاذر
حاذى
حار
حارب
حاز
حاز
حازب
حاس
حاس
حاسب
حاسن
حاش
حاشى
حاص
حاص
حاصر
حاض
حاض
حاض
حاضر
حاط
حاف
حاف
حافر
حافظ
حافى
حاق
حاق
حاق
حاك
حاك
حاك
حاكم
حاكى
حال
حال
حالب
حالف
حام
حامى
حان
حاور
حاول
حايد
حب
حب
حب
حبا
حبا
حبب
حبب
حبج
حبج
حبذ
حبر
حبر
حبر
حبر
حبس
حبس
حبش
حبض
حبط
حبط
حبق
حبق
حبك
حبك
حبك
حبل
حبل
حبل
حبن
حبى
حت
حتأ
حتا
حتد
حتد
حتر
حتر
حتش
حتف
حتك
حتل
حتل
حتم
حتن
حتى
حث
حثا
حثث
حثر
حثل
حثم
حثى
حج
حجأ
حجئ
حجا
حجب
حجب
حجر
حجر
حجز
حجز
حجز
حجل
حجل
حجل
حجل
حجم
حجم
حجن
حجن
حجي
حد
حد
حد
حد
حدأ
حدئ
حدا
حدا
حدب
حدب
حدب
حدث
حدث
حدث
حدث
حدج
حدج
حدد
حدر
حدر
حدر
حدر
حدس
حدس
حدق
حدق
حدل
حدل
حدم
حدم
حدى
حدي
حذ
حذا
حذا
حذر
حذر
حذف
حذق
حذق
حذق
حذق
حذل
حذلق
حذم
حذى
حذي
حر
حر
حر
حرا
حرب
حرب
حرب
حرت
حرت
حرث
حرث
حرج
حرج
حرج
حرح
حرح
حرد
حرد
حرد
حرر
حرز
حرز
حرز
حرز
حرس
حرس
حرس
حرش
حرش
حرش
حرص
حرص
حرص
حرص
حرض
حرض
حرض
حرض
حرض
حرف
حرف
حرف
حرف
حرق
حرق
حرق
حرق
حرك
حرك
حرك
حرك
حرم
حرم
حرم
حرن
حرن
حرى
حز
حزأ
حزا
حزب
حزب
حزر
حزر
حزر
حزز
حزق
حزك
حزم
حزم
حزم
حزم
حزن
حزن
حزن
حزن
حزى
حس
حس
حس
حسا
حسب
حسب
حسب
حسب
حسحس
حسد
حسد
حسر
حسر
حسر
حسر
حسر
حسر
حسر
حسس
حسف
حسف
حسف
حسك
حسل
حسم
حسن
حسن
حسن
حسى
حسى
حسي
حش
حش
حشأ
حشا
حشحش
حشد
حشد
حشر
حشر
حشرج
حشط
حشف
حشف
حشك
حشك
حشل
حشم
حشم
حشن
حشى
حشي
حص
حص
حص
حصأ
حصئ
حصا
حصب
حصب
حصب
حصب
حصحص
حصد
حصد
حصد
حصر
حصر
حصر
حصر
حصرم
حصص
حصف
حصف
حصف
حصل
حصل
حصم
حصن
حصن
حصن
حصن
حصى
حصي
حض
حضأ
حضا
حضب
حضب
حضج
حضر
حضر
حضض
حضل
حضن
حضن
حط
حطأ
حطا
حطب
حطب
حطر
حطم
حطم
حطم
حظ
حظا
حظب
حظب
حظب
حظر
حظر
حظل
حظل
حظل
حظي
حف
حف
حفأ
حفا
حفت
حفحف
حفد
حفر
حفر
حفز
حفس
حفش
حفش
حفص
حفض
حفض
حفظ
حفظ
حفف
حفل
حفن
حفن
حفي
حقا
حقب
حقد
حقد
حقر
حقر
حقر
حقر
حقص
حقط
حقف
حقق
حقل
حقل
حقن
حقن
حقي
حك
حكأ
حكد
حكر
حكر
حكش
حكل
حكم
حكم
حكم
حكى
حل
حل
حل
حل
حل
حل
حلأ
حلئ
حلب
حلب
حلب
حلت
حلج
حلج
حلج
حلج
حلحل
حلز
حلس
حلس
حلس
حلط
حلط
حلف
حلف
حلق
حلق
حلق
حلق
حلق
حلق
حلقم
حلك
حلك
حلل
حلل
حلم
حلم
حلم
حلم
حلو
حلى
حلى
حلي
حلي
حلي
حم
حم
حمأ
حمئ
حما
حمت
حمت
حمت
حمحم
حمد
حمد
حمدل
حمر
حمر
حمر
حمز
حمز
حمس
حمس
حمس
حمش
حمش
حمش
حمش
حمص
حمص
حمض
حمض
حمض
حمض
حمط
حمق
حمق
حمق
حمك
حمك
حمل
حمل
حملق
حمم
حمى
حمى
حمى
حمي
حن
حن
حنأ
حنا
حنب
حنبل
حنث
حنث
حنج
حنجر
حنذ
حنر
حنس
حنش
حنط
حنط
حنط
حنط
حنط
حنط
حنظل
حنف
حنف
حنف
حنق
حنك
حنك
حنك
حنك
حنك
حنن
حنى
حنى
حوج
حوجل
حور
حور
حوز
حوس
حوش
حوص
حوصل
حوض
حوط
حوف
حوق
حوقل
حول
حول
حوم
حوى
حوى
حيا
حيد
حير
حير
حيض
حيعل
حيف
حين
حيي
حيي
خاب
خابر
خات
خاتل
خاتن
خادع
خادن
خاذل
خار
خار
خاز
خاز
خاس
خاس
خاش
خاش
خاشن
خاص
خاص
خاصر
خاصم
خاض
خاضع
خاط
خاطب
خاطر
خاف
خافت
خاق
خال
خال
خالج
خالس
خالص
خالط
خالع
خالف
خالق
خام
خام
خامر
خان
خاير
خايل
خب
خب
خب
خبأ
خبأ
خبئ
خبا
خبت
خبث
خبث
خبج
خبر
خبر
خبر
خبر
خبر
خبز
خبز
خبس
خبش
خبص
خبص
خبط
خبع
خبق
خبل
خبل
خبل
خبل
خبن
خت
خت
خت
ختأ
ختا
ختر
ختر
ختر
ختر
ختع
ختل
ختل
ختم
ختم
ختن
ختن
ختن
ختن
خثر
خثر
خثر
خثر
خثم
خثى
خج
خجأ
خجئ
خجل
خجل
خجى
خجي
خد
خدب
خدب
خدب
خدج
خدج
خدد
خدر
خدر
خدر
خدش
خدش
خدع
خدع
خدف
خدل
خدم
خدم
خدم
خدى
خذأ
خذئ
خذا
خذرف
خذع
خذف
خذق
خذق
خذل
خذل
خذم
خذم
خذي
خر
خر
خرئ
خرب
خرب
خرب
خرب
خربش
خرت
خرث
خرج
خرج
خرج
خرخر
خرد
خرز
خرز
خرز
خرز
خرس
خرس
خرس
خرش
خرش
خرشف
خرص
خرص
خرص
خرص
خرص
خرط
خرط
خرط
خرط
خرع
خرع
خرع
خرف
خرف
خرف
خرق
خرق
خرق
خرق
خرق
خرك
خرم
خرم
خرم
خرم
خز
خز
خزا
خزب
خزج
خزر
خزر
خزر
خزع
خزف
خزق
خزل
خزل
خزم
خزن
خزن
خزن
خزن
خزي
خس
خس
خس
خسأ
خسئ
خسر
خسر
خسر
خسس
خسف
خسف
خسق
خسل
خش
خشا
خشب
خشب
خشب
خشخش
خشر
خشر
خشف
خشف
خشل
خشل
خشم
خشم
خشم
خشن
خشن
خشى
خشي
خص
خص
خص
خصب
خصب
خصخص
خصر
خصص
خصف
خصف
خصف
خصل
خصل
خصم
خصم
خصى
خضب
خضب
خضب
خضد
خضد
خضر
خضر
خضر
خضع
خضع
خضع
خضف
خضل
خضم
خضم
خضم
خضن
خط
خطأ
خطأ
خطئ
خطب
خطب
خطب
خطر
خطط
خطف
خطف
خطل
خطم
خطى
خظا
خع
خف
خف
خف
خفأ
خفا
خفج
خفج
خفخف
خفد
خفد
خفر
خفر
خفر
خفر
خفر
خفر
خفس
خفش
خفش
خفض
خفض
خفض
خفع
خفف
خفى
خفى
خفي
خق
خل
خل
خلأ
خلب
خلب
خلب
خلب
خلب
خلج
خلج
خلج
خلخل
خلد
خلد
خلد
خلد
خلد
خلس
خلس
خلص
خلص
خلص
خلط
خلط
خلع
خلع
خلع
خلف
خلف
خلف
خلف
خلف
خلق
خلق
خلق
خلق
خلل
خلى
خلى
خم
خم
خمج
خمد
خمد
خمر
خمر
خمر
خمس
خمس
خمس
خمش
خمش
خمش
خمص
خمص
خمص
خمط
خمط
خمط
خمع
خمل
خمن
خمن
خمن
خن
خن
خن
خنأ
خنا
خنب
خنث
خنث
خنث
خنخن
خندق
خنز
خنس
خنس
خنس
خنط
خنع
خنف
خنف
خنق
خنق
خنى
خني
خوث
خور
خور
خوص
خوص
خوصص
خوض
خوف
خوق
خول
خول
خون
خوى
خوى
خوي
خيب
خير
خيص
خيط
خيط
خيف
خيل
خيل
خيم
دآ
دأب
دأث
دأظ
دأك
دأل
دأم
دأى
دئص
دئض
دابر
داث
داج
داج
داجن
داجى
داح
داخ
داخ
داخل
داد
دار
دارأ
دارس
دارك
دارى
داس
داش
داص
داع
داعب
داعس
داعك
داعى
داغ
داغش
داف
دافع
داق
داق
دال
دالس
دالك
دام
دامج
دامس
دان
دان
دان
دانى
داه
داهر
داهم
داهن
داهى
داور
داول
داوم
داوى
داين
دب
دب
دبأ
دبج
دبج
دبح
دبخ
دبدب
دبر
دبر
دبر
دبس
دبش
دبغ
دبغ
دبغ
دبق
دبق
دبل
دبل
دبل
دبل
دبلج
دبى
دث
دث
دثر
دثر
دثط
دثع
دج
دجا
دجج
دجدج
دجر
دجل
دجل
دجم
دجن
دجن
دح
دحا
دحا
دحب
دحج
دحر
دحرج
دحز
دحس
دحس
دحص
دحض
دحق
دحل
دحل
دحم
دحن
دحى
دخ
دخ
دخر
دخر
دخس
دخس
دخس
دخش
دخص
دخض
دخل
دخل
دخل
دخم
دخن
دخن
دخن
دخن
دخن
دخن
در
در
در
درأ
درب
درب
درج
درج
درج
درح
درح
درد
دردب
دردر
درز
درز
درس
درس
درس
درس
درس
درس
درس
درس
درص
درع
درع
درع
درق
درك
درم
درم
درم
درن
دره
دروش
درى
دزر
دس
دسا
دسر
دسس
دسع
دسق
دسم
دسم
دسم
دسم
دسى
دش
دشا
دشن
دصق
دظ
دع
دعا
دعب
دعت
دعث
دعث
دعج
دعدع
دعر
دعر
دعز
دعس
دعس
دعص
دعظ
دعق
دعك
دعك
دعل
دعم
دعم
دعن
دغت
دغدغ
دغر
دغر
دغش
دغص
دغف
دغل
دغم
دغم
دغن
دف
دف
دفأ
دفؤ
دفئ
دفا
دفدف
دفر
دفر
دفع
دفف
دفق
دفق
دفق
دفق
دفن
دفي
دق
دق
دقدق
دقر
دقس
دقع
دقق
دقل
دقم
دقم
دقم
دقن
دقي
دك
دكأ
دكدك
دكس
دكس
دكع
دكك
دكل
دكل
دكم
دكن
دكن
دكن
دل
دل
دل
دلا
دلث
دلج
دلج
دلح
دلخ
دلدل
دلس
دلص
دلص
دلظ
دلع
دلع
دلغ
دلق
دلك
دلك
دلل
دلم
دله
دله
دله
دلى
دم
دم
دم
دم
دمث
دمث
دمث
دمج
دمخ
دمدم
دمر
دمس
دمس
دمس
دمس
دمش
دمص
دمص
دمع
دمع
دمغ
دمغ
دمغ
دمق
دمق
دمك
دمل
دمل
دملج
دمم
دمن
دمن
دمن
دمه
دمى
دمي
دن
دنأ
دنؤ
دنئ
دنا
دنح
دنخ
دندن
دنر
دنس
دنس
دنع
دنع
دنف
دنق
دنق
دنن
دنو
دنى
دها
دهث
دهر
دهس
دهس
دهش
دهش
دهف
دهق
دهقن
دهك
دهم
دهم
دهم
دهن
دهن
دهن
دهن
دهو
دهور
دهى
دهى
دهى
دوئ
دوح
دوخ
دود
دود
دور
دوزن
دوس
دوش
دول
دوم
دون
دوى
دوى
دوي
ديث
ديخ
دين
ذآ
ذأب
ذأت
ذأج
ذأح
ذأر
ذأط
ذأف
ذأل
ذأم
ذأى
ذؤب
ذئب
ذئج
ذئر
ذاب
ذاج
ذاج
ذاح
ذاد
ذار
ذاط
ذاط
ذاع
ذاف
ذاف
ذاق
ذاكر
ذال
ذام
ذان
ذاهن
ذب
ذب
ذبب
ذبح
ذبح
ذبذب
ذبر
ذبر
ذبر
ذبر
ذبل
ذج
ذجل
ذح
ذحا
ذحا
ذحج
ذحق
ذحى
ذخر
ذر
ذر
ذرأ
ذرئ
ذرا
ذرب
ذرب
ذرب
ذرح
ذرح
ذرذر
ذرز
ذرع
ذرع
ذرع
ذرع
ذرف
ذرف
ذرف
ذرق
ذرم
ذرى
ذرى
ذعت
ذعج
ذعذع
ذعر
ذعر
ذعط
ذعف
ذعف
ذعق
ذعن
ذغ
ذف
ذف
ذف
ذف
ذفر
ذفط
ذفف
ذقط
ذقن
ذقن
ذقن
ذكا
ذكر
ذكر
ذكر
ذكو
ذكى
ذل
ذلج
ذلغ
ذلغ
ذلف
ذلق
ذلق
ذلق
ذلق
ذلل
ذلى
ذم
ذم
ذمأ
ذمت
ذمر
ذمر
ذمط
ذمل
ذمل
ذمم
ذمه
ذمى
ذمي
ذن
ذن
ذنب
ذنب
ذنب
ذها
ذهب
ذهب
ذهب
ذهر
ذهل
ذهل
ذهن
ذهن
ذوب
ذود
ذوط
ذوى
ذوي
ذيل
رأب
رأد
رأس
رأس
رأس
رأف
رأم
رأى
رأى
رأى
رؤد
رؤف
رئف
رئم
راءى
راب
راب
رابح
رابط
رابع
رابى
راث
راج
راجح
راجع
راجم
راح
راح
راح
راحل
راخ
راخى
راد
راد
رادف
راز
راس
راسل
راش
راش
راشق
راشى
راص
راصد
راض
راضع
راضى
راط
راط
راطن
راع
راع
راعى
راف
راف
رافد
رافع
رافق
راق
راق
راقب
راقص
راكض
راكل
رال
رام
رام
رامح
رامق
رامى
ران
ران
راه
راه
راهق
راهن
راوح
راود
راوغ
رب
ربأ
ربا
ربب
ربت
ربت
ربت
ربث
ربث
ربج
ربح
ربخ
ربخ
ربد
ربد
ربذ
ربز
ربز
ربس
ربش
ربص
ربض
ربض
ربض
ربط
ربط
ربع
ربع
ربع
ربع
ربغ
ربغ
ربغ
ربق
ربق
ربق
ربك
ربك
ربل
ربل
ربى
رت
رتأ
رتا
رتب
رتب
رتج
رتج
رتخ
رتع
رتق
رتق
رتق
رتك
رتك
رتل
رتل
رتم
رتن
رث
رث
رثأ
رثا
رثد
رثد
رثط
رثع
رثم
رثم
رثم
رثى
رج
رج
رجا
رجب
رجب
رجب
رجح
رجح
رجح
رجح
رجد
رجرج
رجز
رجز
رجس
رجس
رجس
رجس
رجع
رجع
رجف
رجل
رجل
رجل
رجم
رجم
رجن
رجن
رجن
رجن
رجى
رح
رحا
رحب
رحب
رحض
رحض
رحل
رحل
رحم
رحم
رحم
رحى
رخ
رخ
رخا
رخا
رخا
رخا
رخص
رخص
رخص
رخف
رخف
رخف
رخم
رخم
رخم
رخم
رخم
رخم
رخم
رخو
رخو
رخى
رخي
رد
رد
ردأ
ردؤ
ردج
ردح
ردح
ردح
ردخ
ردد
ردس
ردس
ردع
ردع
ردغ
ردف
ردف
ردم
ردم
ردن
ردن
رده
ردى
ردى
ردي
رذ
رذل
رذل
رذل
رذم
رذم
رذم
رذي
رز
رز
رزأ
رزئ
رزب
رزح
رزح
رزخ
رزز
رزغ
رزف
رزق
رزم
رزم
رزم
رزن
رزن
رزى
رس
رسا
رسب
رسب
رسح
رسخ
رسخ
رسع
رسع
رسغ
رسف
رسف
رسل
رسل
رسم
رسم
رسم
رسن
رسن
رش
رشا
رشح
رشح
رشد
رشد
رشد
رشف
رشف
رشف
رشق
رشق
رشم
رشم
رشن
رص
رص
رصا
رصد
رصد
رصص
رصع
رصف
رصف
رصف
رصف
رصن
رصن
رصن
رض
رضا
رضب
رضح
رضخ
رضخ
رضد
رضرض
رضع
رضع
رضع
رضع
رضف
رضف
رضم
رضن
رضى
رضي
رطأ
رطئ
رطا
رطب
رطب
رطب
رطب
رطس
رطس
رطل
رطل
رطم
رطن
رطن
رطي
رع
رعا
رعب
رعب
رعبل
رعث
رعث
رعج
رعج
رعد
رعد
رعرع
رعز
رعس
رعش
رعش
رعش
رعص
رعض
رعظ
رعظ
رعف
رعف
رعف
رعف
رعق
رعل
رعل
رعم
رعم
رعن
رعن
رعى
رعى
رعى
رغا
رغا
رغب
رغب
رغب
رغث
رغد
رغد
رغرغ
رغس
رغش
رغف
رغل
رغل
رغم
رغم
رغم
رغم
رغن
رغى
رف
رف
رف
رف
رف
رفأ
رفأ
رفا
رفت
رفت
رفث
رفث
رفد
رفد
رفرف
رفز
رفس
رفس
رفش
رفض
رفض
رفع
رفع
رفع
رفع
رفغ
رفغ
رفق
رفق
رفق
رفق
رفل
رفل
رفل
رفه
رفه
رفه
رق
رق
رقأ
رقا
رقب
رقب
رقح
رقد
رقد
رقرق
رقز
رقش
رقش
رقش
رقص
رقص
رقط
رقط
رقط
رقع
رقع
رقع
رقق
رقم
رقم
رقم
رقن
رقن
رقى
رقى
رقي
رك
رك
ركا
ركب
ركب
ركب
ركح
ركد
ركز
ركز
ركز
ركس
ركض
ركع
ركع
ركك
ركل
ركم
ركن
ركن
ركن
ركن
ركن
رم
رم
رمأ
رمث
رمث
رمج
رمح
رمد
رمد
رمد
رمد
رمد
رمرم
رمز
رمز
رمز
رمس
رمس
رمش
رمش
رمش
رمص
رمص
رمض
رمض
رمض
رمط
رمع
رمع
رمغ
رمق
رمق
رمك
رمل
رمل
رمم
رمه
رمى
رن
رنأ
رنح
رنخ
رنع
رنق
رنق
رنق
رنم
رنم
رنن
رنى
رها
رهب
رهب
رهبل
رهد
رهد
رهز
رهس
رهش
رهص
رهص
رهط
رهط
رهف
رهف
رهق
رهك
رهل
رهل
رهن
روب
روج
روح
رود
روش
روض
روع
روع
روق
روق
رول
روم
روى
روى
روى
روي
ريث
رير
ريش
ريع
ريق
ريم
زأب
زأبق
زأت
زأج
زأد
زأر
زأر
زأط
زأف
زأك
زأم
زأى
زئر
زئم
زاء
زاب
زات
زاج
زاح
زاح
زاحف
زاحم
زاخ
زاخر
زاد
زاد
زار
زار
زارع
زاط
زاع
زاغ
زاغ
زاف
زاف
زاك
زاك
زام
زام
زامل
زامن
زان
زاهق
زاوج
زاول
زايد
زايل
زب
زبب
زبد
زبد
زبد
زبد
زبد
زبر
زبر
زبر
زبر
زبرج
زبط
زبق
زبق
زبل
زبل
زبن
زبى
زبى
زت
زج
زج
زجا
زجج
زجر
زجل
زجل
زجم
زجى
زح
زحب
زحر
زحر
زحر
زحزح
زحف
زحف
زحك
زحل
زحلف
زحلق
زحم
زحن
زخ
زخ
زخر
زخرف
زخف
زخم
زخم
زدا
زدع
زر
زر
زر
زر
زر
زرب
زرب
زرج
زرح
زرح
زرد
زرد
زرد
زرر
زرزر
زرط
زرع
زرف
زرف
زرف
زرف
زرفن
زرق
زرق
زرق
زرك
زركش
زرم
زرم
زرى
زعا
زعب
زعج
زعج
زعر
زعر
زعزع
زعط
زعف
زعفر
زعق
زعق
زعق
زعل
زعم
زعم
زعنف
زغب
زغب
زغد
زغر
زغرد
زغزغ
زغف
زغل
زف
زف
زف
زفت
زفت
زفد
زفر
زفزف
زفن
زفى
زق
زقا
زقب
زقح
زقزق
زقع
زقف
زقق
زقم
زقم
زقن
زقى
زك
زك
زكأ
زكا
زكب
زكت
زكر
زكم
زكن
زكى
زل
زلب
زلج
زلج
زلج
زلح
زلخ
زلخ
زلز
زلزل
زلع
زلع
زلغ
زلف
زلف
زلق
زلق
زلق
زلق
زلل
زلم
زلم
زلم
زله
زم
زم
زمت
زمت
زمج
زمج
زمجر
زمخ
زمخر
زمر
زمر
زمر
زمر
زمزم
زمع
زمع
زمع
زمق
زمق
زمك
زمك
زمل
زمل
زمل
زمل
زمم
زمن
زمه
زمهر
زن
زن
زنأ
زنب
زنج
زنح
زنخ
زنخ
زنخ
زند
زند
زند
زنر
زنر
زنف
زنق
زنق
زنم
زنم
زنم
زنى
زنى
زها
زها
زها
زها
زهد
زهد
زهد
زهد
زهر
زهر
زهر
زهف
زهف
زهق
زهك
زهل
زهل
زهم
زهم
زهى
زوج
زود
زور
زور
زوق
زول
زوى
زيا
زيت
زيد
زير
زيغ
زيف
زيق
زيل
زيل
زيم
زين
سآ
سأب
سأت
سأد
سأر
سأف
سأل
سأى
سؤف
سئب
سئد
سئر
سئس
سئف
سئم
ساء
ساءل
ساب
سابع
سابق
ساتر
ساج
ساجل
ساح
ساح
ساحل
ساخ
ساخف
ساد
سار
سار
سار
سارع
سارق
سارى
ساس
ساط
ساع
ساع
ساعد
ساعف
ساعى
ساغ
ساغ
ساف
ساف
سافح
سافر
سافل
سافه
ساق
ساقط
ساقى
ساك
ساكن
سال
سالم
سام
سامح
سامر
سامى
سانح
ساند
ساهر
ساهل
ساهم
ساهى
ساود
ساور
ساوط
ساوف
ساوم
ساوى
ساير
سايف
سايل
سب
سبأ
سبب
سبح
سبح
سبح
سبحل
سبخ
سبخ
سبخ
سبد
سبر
سبر
سبسب
سبط
سبط
سبط
سبع
سبع
سبع
سبغ
سبق
سبق
سبق
سبك
سبك
سبك
سبل
سبى
ستر
ستر
ستل
ستل
سته
سته
سج
سجا
سجح
سجح
سجد
سجد
سجر
سجر
سجر
سجس
سجس
سجع
سجف
سجف
سجل
سجل
سجم
سجم
سجن
سجن
سجى
سح
سحا
سحا
سحب
سحت
سحت
سحت
سحج
سحر
سحر
سحر
سحط
سحف
سحق
سحق
سحق
سحق
سحل
سحم
سحم
سحن
سحى
سحى
سخ
سخأ
سخر
سخر
سخر
سخط
سخف
سخف
سخل
سخن
سخن
سخن
سخن
سخن
سخو
سخى
سخي
سد
سد
سدا
سدج
سدح
سدد
سدر
سدر
سدر
سدس
سدس
سدس
سدع
سدف
سدك
سدل
سدل
سدل
سدل
سدم
سدم
سدن
سدن
سدى
سدى
سر
سر
سر
سرأ
سرا
سرب
سرب
سربل
سرج
سرج
سرج
سرح
سرح
سرح
سرد
سرد
سرد
سردق
سرر
سرس
سرط
سرط
سرع
سرع
سرغ
سرف
سرف
سرق
سرق
سرق
سرك
سرو
سرول
سرى
سرى
سري
سطأ
سطح
سطح
سطر
سطر
سطع
سطع
سطع
سطع
سطم
سعد
سعد
سعر
سعر
سعر
سعط
سعط
سعف
سعف
سعل
سعم
سعى
سعى
سغب
سغب
سغر
سغل
سغم
سف
سف
سف
سفا
سفت
سفح
سفد
سفد
سفد
سفر
سفر
سفر
سفر
سفسط
سفسف
سفط
سفط
سفع
سفع
سفع
سفك
سفك
سفك
سفل
سفل
سفل
سفل
سفن
سفن
سفن
سفن
سفه
سفه
سفه
سفه
سفه
سفى
سفي
سق
سقب
سقت
سقد
سقر
سقط
سقط
سقع
سقف
سقف
سقل
سقم
سقم
سقى
سقى
سك
سك
سكب
سكت
سكر
سكر
سكر
سكر
سكع
سكع
سكع
سكف
سكم
سكن
سكن
سكن
سل
سل
سلأ
سلا
سلب
سلب
سلب
سلت
سلت
سلج
سلج
سلح
سلح
سلخ
سلخ
سلخ
سلخ
سلس
سلس
سلس
سلسل
سلط
سلط
سلط
سلط
سلطن
سلع
سلع
سلغ
سلغ
سلف
سلف
سلق
سلك
سلك
سلم
سلم
سلم
سلى
سلى
سلي
سلي
سم
سما
سمت
سمت
سمت
سمج
سمج
سمح
سمح
سمخ
سمد
سمر
سمر
سمر
سمر
سمر
سمسر
سمط
سمط
سمط
سمط
سمط
سمع
سمع
سمق
سمك
سمك
سمك
سمل
سمل
سمل
سمم
سمن
سمن
سمن
سمن
سمه
سمى
سن
سنا
سنبل
سنج
سنج
سنح
سنخ
سنخ
سنخ
سند
سنط
سنط
سنع
سنع
سنع
سنف
سنف
سنق
سنم
سنم
سنن
سنه
سنو
سنى
سني
سها
سهب
سهج
سهد
سهد
سهف
سهف
سهك
سهك
سهل
سهل
سهم
سهو
سهى
سود
سود
سور
سوس
سوس
سوس
سوط
سوغ
سوف
سوق
سوق
سول
سول
سوم
سوى
سيب
سيج
سيح
سير
سيس
سيطر
سيع
سيف
سيل
شآ
شأز
شأم
شأن
شؤم
شئز
شئس
شئف
شاء
شاءم
شاءى
شاب
شاب
شابك
شابه
شاتم
شاج
شاجر
شاجع
شاح
شاح
شاحن
شاخ
شاد
شاد
شار
شار
شارب
شارس
شارط
شارف
شارك
شارى
شاس
شاص
شاط
شاطر
شاظ
شاع
شاع
شاعب
شاعر
شاغب
شاغر
شاف
شافه
شاق
شاق
شاقى
شاك
شاك
شاكس
شاكل
شاكى
شال
شال
شام
شام
شان
شانق
شاهد
شاهر
شاور
شايع
شب
شب
شب
شبا
شبب
شبث
شبح
شبح
شبح
شبر
شبر
شبر
شبر
شبع
شبع
شبق
شبك
شبك
شبل
شبم
شبم
شبن
شبه
شت
شتا
شتت
شتر
شتر
شتع
شتغ
شتل
شتم
شتم
شتم
شتم
شتن
شتى
شثر
شثل
شثل
شثن
شثن
شج
شجا
شجب
شجب
شجر
شجر
شجر
شجع
شجع
شجن
شجن
شجن
شجي
شح
شح
شح
شحا
شحب
شحب
شحج
شحج
شحذ
شحر
شحط
شحط
شحط
شحف
شحك
شحل
شحم
شحم
شحم
شحم
شحن
شحن
شحى
شخ
شخب
شخب
شخت
شخر
شخز
شخس
شخص
شخص
شخل
شخم
شخم
شد
شد
شدا
شدح
شدخ
شدد
شدف
شدف
شدق
شدن
شده
شذ
شذا
شذب
شذب
شذب
شذذ
شذر
شر
شر
شر
شر
شرب
شرب
شرب
شرث
شرج
شرج
شرح
شرح
شرخ
شرد
شرد
شرز
شرس
شرس
شرس
شرشر
شرط
شرط
شرط
شرط
شرع
شرع
شرع
شرف
شرف
شرف
شرق
شرق
شرك
شرك
شرم
شرم
شرم
شرن
شرنق
شره
شرى
شرى
شري
شز
شزا
شزب
شزب
شزر
شزر
شزن
شزن
شس
شسب
شسب
شسع
شسع
شسف
شسف
شص
شص
شصا
شصب
شصب
شصر
شصر
شصي
شط
شط
شطأ
شطب
شطب
شطح
شطر
شطر
شطر
شطس
شطط
شطع
شطف
شطم
شطن
شطي
شظ
شظف
شظف
شظف
شظى
شظى
شظي
شع
شعا
شعب
شعب
شعب
شعث
شعر
شعر
شعر
شعر
شعر
شعشع
شعف
شعف
شعل
شعل
شعل
شعن
شعوذ
شعي
شغ
شغا
شغب
شغب
شغر
شغر
شغز
شغف
شغف
شغل
شغل
شغي
شف
شف
شفا
شفر
شفر
شفر
شفز
شفع
شفع
شفف
شفق
شفن
شفن
شفه
شفى
شق
شق
شقأ
شقا
شقح
شقح
شقح
شقذ
شقذ
شقر
شقر
شقشق
شقع
شقق
شقل
شقن
شقن
شك
شكأ
شكئ
شكا
شكد
شكد
شكر
شكر
شكز
شكس
شكس
شكع
شكع
شكك
شكل
شكل
شكل
شكم
شكم
شل
شل
شلا
شلح
شلخ
شلشل
شلغ
شلق
شلوب
شم
شم
شمت
شمت
شمج
شمذ
شمر
شمر
شمر
شمز
شمس
شمس
شمس
شمس
شمص
شمط
شمط
شمظ
شمع
شمع
شمق
شمل
شمل
شمل
شمل
شمم
شن
شن
شن
شنأ
شنئ
شنب
شنث
شنج
شنج
شنص
شنص
شنع
شنع
شنع
شنع
شنف
شنف
شنف
شنف
شنق
شنق
شنق
شنق
شنم
شها
شهب
شهب
شهب
شهد
شهد
شهر
شهر
شهق
شهق
شهق
شهل
شهم
شهم
شهم
شهو
شهى
شور
شوش
شوص
شوط
شوع
شوق
شوك
شوك
شوه
شوه
شوى
شوى
شيأ
شيب
شيت
شيخ
شيد
شيط
شيطن
شيع
شيم
صأم
صأى
صؤل
صئب
صئك
صئم
صاء
صاب
صابر
صات
صات
صاح
صاحب
صاخ
صاخب
صاد
صادر
صادف
صادق
صادم
صادى
صار
صار
صار
صارح
صارع
صارف
صارم
صاص
صاع
صاع
صاعب
صاغ
صاف
صاف
صافح
صافق
صافى
صاق
صاق
صاك
صاك
صال
صالح
صام
صان
صانع
صاهر
صاول
صايح
صايف
صب
صب
صب
صب
صب
صبؤ
صبا
صبح
صبح
صبح
صبح
صبر
صبر
صبر
صبع
صبغ
صبغ
صبغ
صبن
صبن
صت
صتأ
صتا
صتع
صته
صج
صح
صحا
صحب
صحب
صحح
صحر
صحر
صحصح
صحف
صحل
صحن
صحي
صخ
صخب
صخد
صخد
صخر
صخف
صخي
صد
صدأ
صدئ
صدح
صدد
صدر
صدر
صدر
صدر
صدر
صدع
صدع
صدغ
صدغ
صدغ
صدف
صدف
صدق
صدق
صدم
صدى
صدي
صر
صر
صرا
صرب
صرب
صرب
صرح
صرح
صرح
صرد
صرد
صرد
صرر
صرصر
صرع
صرع
صرف
صرف
صرم
صرم
صرم
صرى
صري
صعا
صعب
صعب
صعتر
صعد
صعد
صعر
صعق
صعق
صعل
صعلك
صغ
صغر
صغر
صغر
صغر
صغر
صغي
صف
صفا
صفح
صفح
صفح
صفد
صفد
صفر
صفر
صفر
صفر
صفصف
صفع
صفغ
صفف
صفق
صفق
صفق
صفن
صفو
صفى
صق
صقب
صقب
صقر
صقر
صقع
صقع
صقع
صقل
صقل
صك
صكا
صكم
صل
صل
صلا
صلب
صلب
صلب
صلب
صلت
صلت
صلت
صلج
صلج
صلح
صلح
صلح
صلح
صلخ
صلد
صلصل
صلع
صلع
صلف
صلف
صلق
صلق
صلم
صلى
صلى
صلى
صلي
صم
صم
صم
صمأ
صمت
صمت
صمح
صمح
صمخ
صمد
صمد
صمر
صمر
صمر
صمصم
صمع
صمع
صمغ
صمل
صمم
صمى
صن
صنج
صنخ
صنع
صنع
صنع
صنف
صنق
صنم
صنم
صها
صهب
صهب
صهب
صهد
صهر
صهل
صهل
صهى
صهي
صهين
صوب
صوبن
صوت
صور
صور
صوف
صوف
صول
صوم
صومع
صوى
صوى
صوي
صيح
صيد
صيدل
صير
صيف
ضأد
ضأز
ضأضأ
ضأى
ضؤل
ضئط
ضاء
ضاءل
ضاب
ضاج
ضاج
ضاجع
ضاح
ضاحك
ضاد
ضار
ضار
ضار
ضارب
ضارس
ضارع
ضاز
ضاز
ضاس
ضاس
ضاط
ضاع
ضاع
ضاعف
ضاغط
ضاغن
ضاف
ضافر
ضاق
ضاك
ضاك
ضام
ضام
ضان
ضاهى
ضايق
ضب
ضب
ضبأ
ضبا
ضبث
ضبج
ضبح
ضبد
ضبر
ضبر
ضبس
ضبس
ضبط
ضبط
ضبط
ضبع
ضبع
ضبن
ضبن
ضبى
ضج
ضجر
ضجع
ضجم
ضحا
ضحا
ضحك
ضحك
ضحل
ضحى
ضحي
ضخ
ضخز
ضخم
ضخم
ضد
ضدئ
ضدن
ضدي
ضر
ضرأ
ضرا
ضرب
ضرب
ضرب
ضرب
ضرج
ضرج
ضرج
ضرح
ضرح
ضرح
ضرر
ضرس
ضرس
ضرس
ضرس
ضرط
ضرع
ضرع
ضرك
ضرم
ضرم
ضرى
ضز
ضزن
ضزن
ضع
ضعا
ضعز
ضعضع
ضعط
ضعف
ضعف
ضعف
ضغا
ضغب
ضغث
ضغث
ضغط
ضغل
ضغم
ضغن
ضف
ضفا
ضفد
ضفدع
ضفر
ضفر
ضفز
ضفس
ضفط
ضفط
ضفع
ضفق
ضفن
ضك
ضكز
ضل
ضلع
ضلع
ضلع
ضلع
ضلل
ضم
ضمج
ضمخ
ضمخ
ضمد
ضمد
ضمد
ضمد
ضمر
ضمر
ضمز
ضمز
ضمس
ضمضم
ضمن
ضمن
ضمى
ضمي
ضن
ضن
ضنأ
ضنئ
ضنا
ضنب
ضنط
ضنك
ضنك
ضنى
ضني
ضهب
ضهت
ضهد
ضهز
ضهس
ضهل
ضهي
ضوأ
ضوط
ضوى
ضوي
ضيع
ضيف
ضيق
طأطأ
طأمن
طاء
طاب
طابق
طاح
طاخ
طاخ
طاد
طار
طار
طارح
طارد
طاس
طاش
طاط
طاط
طاع
طاعم
طاعن
طاف
طاق
طالب
طالع
طام
طان
طاوح
طاوع
طاول
طايب
طاير
طب
طب
طبا
طبب
طبج
طبخ
طبخ
طبخ
طبر
طبز
طبطب
طبع
طبع
طبع
طبق
طبق
طبل
طبل
طبن
طبن
طبى
طبي
طث
طثأ
طثا
طثر
طجن
طح
طحا
طحث
طحر
طحر
طحز
طحس
طحل
طحل
طحلب
طحن
طحن
طحى
طحى
طخ
طخا
طخش
طخم
طخم
طر
طرأ
طرؤ
طرا
طرب
طرب
طرح
طرح
طرد
طرد
طرر
طرز
طرز
طرس
طرس
طرس
طرش
طرط
طرف
طرف
طرف
طرف
طرق
طرق
طرق
طرم
طرو
طري
طس
طسأ
طسئ
طسا
طسع
طسع
طسل
طسم
طسم
طسى
طسي
طش
طش
طع
طعج
طعر
طعز
طعس
طعل
طعم
طعم
طعن
طعن
طعن
طعن
طغا
طغر
طغى
طغي
طف
طفئ
طفا
طفح
طفح
طفذ
طفر
طفر
طفس
طفس
طفش
طفطف
طفف
طفق
طفل
طفل
طفن
طق
طقطق
طل
طل
طل
طلا
طلب
طلب
طلب
طلث
طلح
طلح
طلح
طلح
طلس
طلس
طلس
طلس
طلسم
طلع
طلع
طلع
طلع
طلغ
طلق
طلق
طلق
طلق
طلق
طلم
طلم
طلمس
طله
طلى
طلى
طلي
طم
طم
طمأن
طما
طمث
طمث
طمث
طمث
طمح
طمح
طمر
طمر
طمر
طمر
طمس
طمس
طمع
طمع
طمع
طمغ
طمل
طمل
طمى
طن
طنأ
طنئ
طنب
طنب
طنح
طنخ
طنطن
طنف
طنن
طني
طها
طها
طهر
طهر
طهر
طهس
طهش
طهق
طهل
طهل
طهى
طوح
طور
طوس
طوع
طوع
طوف
طوق
طول
طول
طول
طوى
طوي
طيب
طيح
طير
طيط
طيف
طين
ظأب
ظأت
ظأر
ظأف
ظاف
ظالم
ظاهر
ظج
ظر
ظرب
ظرف
ظرى
ظري
ظعن
ظف
ظفر
ظفر
ظفر
ظل
ظل
ظل
ظل
ظلف
ظلف
ظلف
ظلل
ظلم
ظلم
ظلم
ظمأ
ظمئ
ظمي
ظن
ظهر
ظهر
ظهر
عاب
عاتب
عاج
عاجز
عاجل
عاد
عاد
عاد
عادل
عادى
عاذ
عار
عارض
عارك
عارم
عاز
عاس
عاس
عاسر
عاشر
عاص
عاصر
عاصى
عاض
عاض
عاضد
عاط
عاط
عاطش
عاظل
عاف
عافى
عاق
عاق
عاق
عاقب
عاقد
عاقر
عاقل
عاك
عاك
عاكس
عاكف
عال
عالج
عالم
عالن
عالى
عام
عامل
عان
عان
عاند
عانق
عانى
عاه
عاه
عاهد
عاهر
عاود
عاور
عاوص
عاوض
عاوم
عاون
عاوى
عايد
عاير
عايش
عاين
عب
عبأ
عبأ
عبا
عبت
عبث
عبث
عبد
عبد
عبد
عبر
عبر
عبر
عبر
عبر
عبر
عبس
عبس
عبش
عبط
عبق
عبق
عبقر
عبك
عبل
عبل
عبل
عبل
عبم
عبى
عبى
عت
عتا
عتب
عتب
عتب
عتب
عتب
عتد
عتد
عتر
عترس
عتف
عتق
عتق
عتق
عتق
عتك
عتل
عتل
عتل
عتم
عتم
عتن
عتن
عته
عتي
عث
عثا
عثج
عثر
عثر
عثر
عثر
عثر
عثر
عثر
عثل
عثل
عثم
عثم
عثم
عثن
عثن
عثي
عجا
عجب
عجب
عجج
عجر
عجر
عجز
عجز
عجز
عجز
عجز
عجس
عجف
عجف
عجف
عجف
عجف
عجل
عجل
عجم
عجم
عجم
عجن
عجن
عجن
عجي
عد
عدا
عدد
عدر
عدس
عدف
عدق
عدق
عدك
عدل
عدل
عدل
عدم
عدم
عدن
عدن
عدى
عدي
عذا
عذب
عذب
عذب
عذر
عذر
عذر
عذر
عذر
عذف
عذق
عذق
عذل
عذل
عذل
عذم
عذم
عذو
عذي
عر
عر
عر
عر
عرا
عرب
عرب
عرب
عرب
عربد
عربن
عرت
عرت
عرت
عرج
عرج
عرج
عرج
عرج
عرد
عرد
عرز
عرز
عرس
عرس
عرس
عرس
عرش
عرش
عرش
عرش
عرص
عرص
عرض
عرض
عرض
عرض
عرض
عرط
عرف
عرف
عرف
عرف
عرف
عرق
عرق
عرق
عرق
عرقل
عرك
عرك
عرم
عرم
عرم
عرم
عرم
عرن
عرن
عرن
عرن
عرى
عز
عز
عز
عزا
عزب
عزب
عزب
عزب
عزج
عزد
عزر
عزر
عزر
عزز
عزف
عزف
عزف
عزق
عزق
عزق
عزل
عزم
عزى
عزى
عزي
عس
عسا
عسب
عسج
عسج
عسد
عسر
عسر
عسر
عسر
عسر
عسعس
عسف
عسف
عسق
عسقل
عسك
عسكر
عسل
عسل
عسل
عسم
عسم
عسن
عسي
عسي
عش
عش
عشا
عشا
عشب
عشب
عشب
عشد
عشر
عشر
عشر
عشر
عشر
عشز
عشش
عشط
عشم
عشن
عشى
عص
عصا
عصب
عصب
عصب
عصد
عصد
عصد
عصر
عصر
عصف
عصف
عصل
عصل
عصم
عصم
عصم
عصى
عصي
عض
عضا
عضب
عضب
عضب
عضد
عضد
عضد
عضر
عضل
عضل
عضل
عضل
عضه
عضه
عط
عطا
عطب
عطب
عطب
عطر
عطر
عطس
عطس
عطس
عطش
عطش
عطف
عطف
عطل
عطل
عطن
عطن
عطن
عطى
عظ
عظا
عظب
عظب
عظر
عظر
عظل
عظل
عظل
عظم
عظم
عظم
عظم
عظى
عظي
عفا
عفت
عفت
عفج
عفج
عفد
عفر
عفر
عفر
عفس
عفش
عفص
عفص
عفط
عفق
عفك
عفك
عفل
عفل
عفن
عفن
عفن
عفه
عفى
عق
عق
عق
عقا
عقب
عقب
عقب
عقب
عقد
عقد
عقد
عقر
عقر
عقر
عقرب
عقص
عقص
عقعق
عقف
عقف
عقل
عقل
عقل
عقل
عقل
عقل
عقم
عقم
عقم
عقم
عقم
عقى
عك
عك
عكا
عكب
عكب
عكد
عكد
عكر
عكر
عكر
عكز
عكز
عكس
عكش
عكش
عكش
عكص
عكص
عكظ
عكف
عكف
عكل
عكل
عكل
عكم
عكى
عل
عل
علا
علب
علب
علب
علب
علث
علث
علج
علج
علد
علز
علس
علض
علط
علط
علف
علف
علق
علق
علق
علقم
علك
علك
علك
علل
علم
علم
علم
علم
علمن
علن
علن
علن
علن
علن
عله
على
على
عم
عم
عمت
عمج
عمد
عمد
عمر
عمر
عمر
عمر
عمر
عمر
عمر
عمر
عمر
عمس
عمس
عمس
عمس
عمش
عمش
عمش
عمط
عمق
عمق
عمق
عمل
عمل
عمم
عمن
عمن
عمه
عمه
عمه
عمى
عمى
عمي
عمي
عن
عن
عنا
عنا
عنب
عنبر
عنت
عنت
عنتر
عنج
عنج
عند
عند
عند
عندل
عنز
عنس
عنس
عنش
عنش
عنعن
عنف
عنف
عنق
عنق
عنق
عنك
عنن
عنون
عنى
عنى
عنى
عنى
عهب
عهد
عهر
عهن
عهن
عوج
عوج
عوج
عود
عوذ
عور
عوز
عوس
عوص
عوص
عوض
عوق
عول
عولم
عوم
عوى
عوى
عوى
عي
عي
عيا
عيب
عيد
عير
عيش
عيط
عيط
عيف
عيل
عيم
عين
عين
غاب
غاث
غاث
غاج
غادر
غار
غار
غار
غارق
غارى
غاز
غازل
غاص
غاضب
غاط
غاف
غال
غالب
غالط
غالى
غام
غامر
غامس
غان
غايب
غاير
غايظ
غب
غب
غبأ
غبث
غبث
غبج
غبر
غبر
غبس
غبس
غبش
غبش
غبص
غبط
غبط
غبق
غبق
غبن
غبن
غبن
غبي
غت
غتل
غتم
غتم
غث
غث
غث
غث
غثر
غثر
غثم
غثم
غثى
غد
غدر
غدر
غدر
غدف
غدق
غدق
غدن
غدى
غدي
غذ
غذ
غذا
غذم
غذم
غذى
غر
غر
غر
غر
غر
غر
غرا
غرب
غرب
غرب
غرب
غرب
غرب
غرب
غربل
غرث
غرد
غرد
غرر
غرز
غرز
غرز
غرس
غرض
غرض
غرض
غرغر
غرف
غرف
غرف
غرق
غرق
غرل
غرم
غرم
غرن
غرى
غرى
غري
غز
غزا
غزا
غزر
غزل
غزل
غزى
غس
غسا
غسر
غسق
غسق
غسل
غسل
غسم
غسن
غسي
غش
غشا
غشش
غشم
غشى
غشي
غشي
غص
غصب
غصن
غصن
غض
غض
غض
غضا
غضب
غضر
غضر
غضر
غضر
غضر
غضض
غضف
غضف
غضن
غضن
غضن
غضن
غط
غط
غطا
غطرس
غطرف
غطس
غطس
غطش
غطش
غطف
غطل
غطل
غطى
غطى
غفا
غفر
غفر
غفق
غفق
غفل
غفل
غفى
غق
غل
غل
غل
غل
غلا
غلا
غلب
غلب
غلب
غلت
غلت
غلث
غلث
غلج
غلس
غلط
غلط
غلظ
غلظ
غلظ
غلغل
غلف
غلف
غلف
غلق
غلق
غلق
غلم
غلم
غلن
غلى
غلى
غلي
غم
غم
غما
غمت
غمت
غمج
غمج
غمد
غمد
غمد
غمر
غمر
غمر
غمز
غمس
غمس
غمش
غمص
غمص
غمض
غمض
غمض
غمض
غمض
غمض
غمط
غمط
غمق
غمق
غمق
غمل
غمل
غمن
غمى
غن
غنث
غنث
غنج
غنص
غنض
غنظ
غنم
غنى
غني
غهب
غوص
غوى
غوي
غيب
غيد
غير
غير
غيس
غيض
غيظ
غيم
غين
فآ
فأد
فأر
فأس
فأق
فأم
فأى
فئد
فئق
فاء
فات
فاتح
فاتك
فاج
فاج
فاجأ
فاجر
فاح
فاح
فاح
فاخ
فاخ
فاخر
فاد
فاد
فادى
فارز
فارس
فارض
فارط
فارع
فارق
فاز
فاسخ
فاسد
فاص
فاصل
فاض
فاض
فاضل
فاطن
فاظ
فاظ
فاع
فاغ
فاف
فاق
فاق
فاقم
فاقه
فاكه
فال
فان
فاه
فاوض
فايش
فت
فتأ
فتئ
فتا
فتت
فتح
فتح
فتخ
فتخ
فتر
فتر
فتر
فتش
فتش
فتغ
فتق
فتق
فتق
فتق
فتل
فتل
فتل
فتن
فتن
فتن
فتو
فتي
فث
فثأ
فثئ
فثج
فثغ
فج
فج
فجأ
فجئ
فجا
فجر
فجر
فجس
فجش
فجع
فجع
فجل
فجل
فجم
فجي
فجي
فح
فح
فحا
فحث
فحج
فحج
فحس
فحش
فحش
فحش
فحص
فحض
فحفح
فحل
فحم
فحم
فحم
فحم
فحم
فحى
فحي
فخ
فخ
فخت
فخج
فخج
فخذ
فخذ
فخر
فخر
فخر
فخز
فخز
فخش
فخفخ
فخم
فخم
فد
فدح
فدخ
فدر
فدر
فدش
فدع
فدع
فدغ
فدم
فدم
فدم
فدن
فدى
فدى
فذ
فذ
فذلك
فر
فرت
فرت
فرت
فرتك
فرث
فرث
فرث
فرج
فرج
فرج
فرج
فرح
فرح
فرخ
فرخ
فرد
فرد
فرد
فرد
فرز
فرز
فرس
فرس
فرس
فرس
فرش
فرش
فرش
فرص
فرص
فرض
فرض
فرض
فرط
فرط
فرط
فرطح
فرطس
فرع
فرع
فرع
فرعن
فرغ
فرغ
فرغ
فرفر
فرق
فرق
فرق
فرق
فرقع
فرك
فرك
فرم
فرمل
فره
فره
فره
فرى
فرى
فري
فز
فز
فز
فز
فزر
فزر
فزر
فزع
فزع
فزع
فسأ
فسئ
فسا
فسج
فسح
فسح
فسح
فسخ
فسخ
فسد
فسد
فسر
فسر
فسر
فسفس
فسق
فسق
فسل
فسل
فسل
فسل
فش
فشأ
فشا
فشج
فشح
فشخ
فشع
فشغ
فشغ
فشفش
فشق
فشق
فشل
فشل
فص
فصح
فصح
فصح
فصخ
فصد
فصد
فصص
فصع
فصفص
فصل
فصل
فصل
فصم
فصى
فصى
فض
فضح
فضح
فضح
فضخ
فضض
فضع
فضغ
فضفض
فضل
فضل
فضل
فضل
فطأ
فطئ
فطا
فطح
فطح
فطح
فطر
فطر
فطر
فطس
فطس
فطس
فطم
فطن
فطن
فطن
فطه
فظ
فظع
فظع
فعر
فعل
فعل
فعم
فعم
فعم
فغ
فغا
فغر
فغر
فغم
فغم
فغي
فق
فق
فقأ
فقا
فقح
فقخ
فقد
فقر
فقر
فقر
فقر
فقر
فقس
فقش
فقص
فقع
فقع
فقع
فقع
فقم
فقم
فقم
فقه
فقه
فقه
فك
فك
فك
فكر
فكر
فكر
فكع
فكع
فكك
فكن
فكه
فكه
فل
فل
فل
فل
فل
فلأ
فلا
فلج
فلج
فلج
فلج
فلح
فلح
فلح
فلخ
فلذ
فلس
فلس
فلسف
فلط
فلطح
فلع
فلغ
فلفل
فلق
فلق
فلك
فلك
فلى
فلى
فلي
فن
فنح
فنخ
فند
فند
فنس
فنع
فنق
فنك
فنك
فنن
فني
فه
فها
فهد
فهد
فهر
فهرس
فهق
فهق
فهم
فهم
فوت
فوج
فوز
فوض
فوط
فوق
فوق
فوه
فوه
فيأ
فيح
فيح
قأب
قأى
قئب
قئم
قاء
قاب
قابض
قابل
قات
قاتل
قاح
قاحل
قاخ
قاد
قادر
قاذع
قار
قار
قارأ
قارب
قارح
قارص
قارض
قارع
قارف
قارن
قاس
قاس
قاسح
قاسم
قاسى
قاص
قاص
قاض
قاض
قاضم
قاضى
قاطع
قاظ
قاع
قاف
قاق
قاق
قال
قالع
قام
قامر
قان
قانى
قاهر
قاول
قاوم
قايس
قايض
قايظ
قب
قب
قب
قب
قب
قب
قبا
قبب
قبث
قبح
قبح
قبح
قبر
قبر
قبس
قبس
قبس
قبص
قبص
قبض
قبض
قبط
قبقب
قبل
قبل
قبل
قبل
قبل
قبن
قبن
قبى
قت
قتا
قتب
قتت
قتد
قتر
قتر
قتر
قتر
قتع
قتل
قتل
قتم
قتم
قتم
قتن
قتن
قث
قثا
قثم
قثم
قثم
قثم
قثى
قح
قحا
قحب
قحب
قحث
قحد
قحر
قحز
قحص
قحط
قحف
قحل
قحل
قحم
قحم
قحم
قخا
قخر
قد
قدا
قدح
قدح
قدد
قدر
قدر
قدر
قدر
قدر
قدس
قدس
قدع
قدع
قدف
قدم
قدم
قدم
قدم
قدو
قدى
قدي
قذ
قذذ
قذر
قذر
قذر
قذر
قذع
قذف
قذل
قذم
قذم
قذى
قذي
قر
قر
قر
قر
قر
قر
قرأ
قرا
قرب
قرب
قرب
قرب
قرت
قرت
قرث
قرث
قرح
قرح
قرح
قرد
قرد
قرد
قرر
قرس
قرس
قرس
قرش
قرش
قرش
قرش
قرص
قرص
قرص
قرض
قرض
قرض
قرط
قرط
قرط
قرطس
قرظ
قرظ
قرظ
قرع
قرع
قرع
قرف
قرف
قرف
قرفص
قرق
قرق
قرق
قرقر
قرم
قرم
قرم
قرمد
قرمط
قرن
قرن
قرن
قره
قرى
قرى
قري
قز
قز
قزا
قزب
قزح
قزح
قزع
قزع
قزل
قزل
قزم
قزم
قس
قسا
قسب
قسب
قسح
قسر
قسط
قسط
قسط
قسط
قسم
قسم
قسم
قسى
قش
قش
قشا
قشب
قشب
قشب
قشب
قشد
قشر
قشر
قشر
قشر
قشط
قشط
قشع
قشع
قشف
قشف
قشف
قشقش
قشم
قص
قص
قصب
قصب
قصد
قصد
قصد
قصر
قصر
قصر
قصر
قصر
قصر
قصر
قصص
قصع
قصع
قصع
قصف
قصف
قصل
قصم
قصم
قض
قض
قض
قض
قض
قضئ
قضب
قضب
قضع
قضف
قضقض
قضم
قضى
قضى
قط
قط
قط
قط
قط
قط
قطا
قطب
قطب
قطر
قطر
قطرب
قطط
قطع
قطع
قطع
قطع
قطف
قطف
قطف
قطف
قطف
قطل
قطل
قطم
قطم
قطم
قطن
قطن
قطن
قع
قعا
قعث
قعد
قعد
قعد
قعر
قعر
قعر
قعز
قعس
قعس
قعش
قعص
قعص
قعط
قعط
قعف
قعف
قعقع
قعم
قعم
قعن
قعي
قف
قفئ
قفا
قفح
قفخ
قفد
قفد
قفر
قفر
قفز
قفز
قفس
قفس
قفس
قفش
قفص
قفص
قفص
قفط
قفط
قفع
قفع
قفقف
قفل
قفل
قفل
قفل
قفل
قفل
قفن
قفى
قفى
قلا
قلب
قلب
قلب
قلب
قلت
قلح
قلخ
قلد
قلد
قلز
قلز
قلس
قلص
قلص
قلع
قلع
قلع
قلف
قلف
قلف
قلق
قلق
قلقل
قلل
قلل
قلم
قلم
قلى
قلى
قلي
قم
قمأ
قمؤ
قما
قمح
قمح
قمد
قمد
قمر
قمر
قمر
قمز
قمس
قمس
قمش
قمش
قمص
قمص
قمص
قمط
قمط
قمط
قمطر
قمع
قمع
قمع
قمقم
قمل
قمم
قمن
قمن
قمه
قمه
قمى
قن
قنأ
قنئ
قنا
قنب
قنبل
قنت
قنح
قند
قنص
قنط
قنط
قنط
قنط
قنطر
قنع
قنع
قنف
قنم
قنى
قه
قهب
قهد
قهر
قهز
قهقر
قهقه
قهل
قهل
قهم
قهي
قود
قود
قور
قوس
قوس
قوض
قول
قولب
قوم
قوى
قوي
قوي
قيأ
قيح
قيد
قيض
قيظ
قيل
قيم
قين
كأج
كأد
كأش
كأص
كأكأ
كأل
كأى
كئب
كاء
كاء
كاب
كابد
كابر
كاتب
كاتم
كاثر
كاح
كاح
كاد
كاذب
كار
كارم
كارى
كاز
كاس
كاسح
كاش
كاشح
كاشر
كاشف
كاص
كاع
كاع
كاف
كافأ
كافح
كافر
كافل
كال
كالب
كالح
كالم
كام
كانف
كاه
كاه
كاهل
كايد
كايل
كب
كبا
كبب
كبت
كبت
كبث
كبث
كبح
كبد
كبد
كبد
كبد
كبر
كبر
كبر
كبر
كبس
كبس
كبس
كبش
كبش
كبع
كبكب
كبل
كبل
كبن
كبن
كبى
كت
كت
كتا
كتب
كتب
كتب
كتح
كتع
كتف
كتف
كتف
كتكت
كتل
كتل
كتل
كتم
كتم
كتن
كته
كث
كث
كثأ
كثب
كثب
كثب
كثج
كثح
كثر
كثر
كثر
كثع
كثع
كثف
كثف
كثم
كثم
كج
كح
كحب
كحث
كحص
كحل
كحل
كحل
كحل
كخ
كخم
كد
كدأ
كدئ
كدج
كدح
كدح
كدر
كدر
كدر
كدر
كدس
كدس
كدش
كدع
كدم
كدم
كدن
كدن
كده
كدى
كدي
كذ
كذب
كذب
كر
كر
كر
كرا
كرب
كرب
كرب
كرتن
كرث
كرث
كرج
كرد
كرر
كرز
كرز
كرس
كرس
كرش
كرش
كرص
كرض
كرظ
كرع
كرع
كرف
كرف
كركر
كرم
كرم
كرم
كره
كره
كره
كرى
كري
كز
كزب
كزم
كزم
كزم
كزى
كس
كس
كسأ
كسا
كسب
كسب
كسح
كسح
كسد
كسد
كسر
كسر
كسع
كسف
كسف
كسف
كسكس
كسل
كسم
كسي
كشأ
كشئ
كشا
كشب
كشح
كشح
كشح
كشد
كشر
كشر
كشر
كشط
كشع
كشف
كشف
كشف
كشكش
كشم
كشم
كص
كصم
كصى
كظ
كظ
كظا
كظب
كظر
كظم
كظم
كظم
كع
كعا
كعب
كعب
كعب
كعر
كعز
كعل
كعم
كف
كفأ
كفت
كفح
كفح
كفخ
كفر
كفر
كفر
كفس
كفكف
كفل
كفل
كفل
كفل
كفل
كفن
كفن
كفى
كل
كلأ
كلأ
كلئ
كلب
كلب
كلب
كلت
كلثم
كلح
كلح
كلد
كلز
كلس
كلس
كلس
كلع
كلع
كلف
كلف
كلل
كلم
كلم
كلى
كم
كم
كمأ
كمئ
كمت
كمت
كمت
كمح
كمخ
كمد
كمد
كمد
كمر
كمز
كمس
كمش
كمش
كمش
كمش
كمع
كمكم
كمل
كمل
كمل
كمل
كمم
كمن
كمن
كمه
كمى
كن
كنا
كنب
كنب
كنب
كنت
كنت
كند
كند
كنز
كنز
كنس
كنس
كنس
كنش
كنظ
كنظ
كنع
كنع
كنف
كنف
كنف
كنه
كنى
كنى
كه
كه
كهب
كهب
كهد
كهر
كهرب
كهل
كهل
كهم
كهم
كهن
كهن
كهن
كهي
كوب
كود
كور
كوع
كوع
كوكب
كوم
كوم
كون
كوه
كوى
كوى
كيح
كيس
كيف
كيل
لأط
لأظ
لأف
لألأ
لأم
لأى
لؤم
لاءم
لاب
لابس
لات
لات
لاث
لاج
لاج
لاح
لاحظ
لاحف
لاحق
لاحم
لاحن
لاحى
لاخ
لاد
لاذ
لاز
لاز
لازق
لازم
لاس
لاسن
لاشى
لاص
لاص
لاصق
لاط
لاطف
لاطم
لاظ
لاظ
لاع
لاعب
لاعج
لاعن
لاغ
لاغى
لاف
لاف
لاف
لاقى
لاك
لاكز
لاكم
لام
لامح
لامس
لان
لاه
لاه
لاين
لب
لب
لب
لب
لب
لب
لبأ
لبب
لبب
لبب
لبب
لبب
لبت
لبث
لبث
لبج
لبح
لبخ
لبد
لبد
لبد
لبد
لبد
لبد
لبز
لبس
لبس
لبس
لبط
لبق
لبق
لبق
لبك
لبك
لبك
لبلب
لبن
لبن
لبن
لبن
لبنن
لبى
لبي
لت
لتأ
لتب
لتح
لتح
لتد
لتز
لتز
لتم
لثأ
لثد
لثغ
لثغ
لثق
لثم
لثم
لثم
لثي
لج
لج
لجأ
لجأ
لجئ
لجب
لجب
لجذ
لجذ
لجف
لجف
لجلج
لجم
لجم
لجن
لجن
لح
لح
لح
لحا
لحب
لحب
لحت
لحج
لحج
لحد
لحز
لحز
لحس
لحس
لحس
لحص
لحص
لحط
لحظ
لحف
لحف
لحق
لحك
لحك
لحم
لحم
لحم
لحم
لحم
لحم
لحن
لحن
لحن
لحى
لحى
لخ
لخا
لخب
لخب
لخبط
لخص
لخص
لخص
لخف
لخم
لخم
لخن
لخن
لخى
لخي
لد
لد
لد
لدد
لدس
لدغ
لدك
لدم
لدن
لدن
لذ
لذج
لذذ
لذع
لذم
لذي
لز
لزأ
لزب
لزب
لزب
لزب
لزج
لزق
لزق
لزم
لزن
لزن
لس
لسب
لسب
لسد
لسد
لسع
لسم
لسم
لسن
لسن
لسن
لشا
لص
لص
لصا
لصب
لصص
لصغ
لصف
لصف
لصف
لصق
لصى
لصي
لضا
لضم
لط
لطأ
لطئ
لطا
لطث
لطح
لطخ
لطخ
لطس
لطع
لطع
لطف
لطف
لطف
لطم
لطم
لطه
لطى
لطي
لظ
لظى
لظي
لعب
لعب
لعب
لعث
لعج
لعز
لعس
لعس
لعص
لعض
لعط
لعق
لعق
لعلع
لعن
لعن
لغب
لغب
لغب
لغد
لغز
لغط
لغط
لغف
لغف
لغم
لغم
لغم
لغي
لف
لفأ
لفئ
لفا
لفت
لفت
لفت
لفح
لفخ
لفظ
لفع
لفع
لفف
لفق
لفق
لفق
لفلف
لفم
لق
لقا
لقب
لقث
لقث
لقح
لقح
لقز
لقس
لقس
لقس
لقص
لقص
لقط
لقع
لقف
لقف
لقلق
لقم
لقم
لقم
لقن
لقن
لقن
لقى
لقي
لك
لكأ
لكئ
لكث
لكث
لكح
لكد
لكد
لكز
لكش
لكع
لكع
لكع
لكم
لكن
لكي
لم
لمأ
لما
لمج
لمج
لمح
لمح
لمخ
لمز
لمز
لمس
لمس
لمص
لمط
لمظ
لمع
لمق
لمك
لملم
لمى
لمي
له
لها
لها
لهب
لهب
لهث
لهث
لهج
لهد
لهز
لهزم
لهس
لهط
لهع
لهف
لهف
لهق
لهق
لهم
لهى
لوث
لوح
لود
لوز
لوط
لوع
لوق
لوم
لون
لوى
لوى
لوى
ليس
ليس
ليف
ليمن
لين
مآ
مأج
مأد
مأر
مأس
مأش
مأل
مأمأ
مأن
مأى
مؤج
مؤل
مئر
مئس
مئق
مئل
ماء
ماث
ماث
ماثل
ماج
ماجد
ماح
ماحض
ماحك
ماحل
ماخ
ماد
مار
مارس
مارى
ماز
مازج
مازح
ماس
ماسح
ماش
ماش
ماشى
ماص
ماط
ماطل
ماع
ماغ
ماقت
ماكر
ماكس
مال
مالأ
مالح
مالق
مان
مان
مانح
مانع
ماه
ماهر
متا
متح
متخ
متخ
متد
متر
متش
متش
متع
متع
متك
متل
متن
متن
متن
مته
مته
متى
مث
مثج
مثد
مثع
مثع
مثع
مثل
مثل
مثل
مثل
مثن
مثن
مثن
مج
مجح
مجح
مجد
مجد
مجد
مجر
مجع
مجع
مجع
مجع
مجل
مجل
مجن
مجن
مح
مح
مح
محا
محت
محت
محج
محز
محش
محص
محص
محض
محض
محض
محط
محق
محك
محك
محل
محل
محل
محل
محل
محن
محور
محى
محى
مخج
مخخ
مخر
مخر
مخض
مخض
مخض
مخض
مخط
مخط
مخط
مخق
مخن
مد
مدح
مدخ
مدد
مدر
مدر
مدس
مدش
مدش
مدق
مدن
مدن
مده
مذح
مذر
مذر
مذع
مذق
مذل
مذل
مذل
مذى
مر
مر
مرأ
مرؤ
مرؤ
مرت
مرث
مرث
مرث
مرج
مرج
مرح
مرحب
مرخ
مرخ
مرخ
مرد
مرد
مرد
مرد
مرذ
مرر
مرز
مرس
مرس
مرش
مرص
مرص
مرض
مرض
مرط
مرط
مرع
مرع
مرع
مرغ
مرغ
مرق
مرق
مرق
مرق
مركز
مرمر
مرن
مرن
مره
مرهم
مرى
مز
مز
مزا
مزج
مزج
مزح
مزح
مزر
مزر
مزع
مزق
مزق
مزن
مزى
مس
مسأ
مسا
مسح
مسح
مسح
مسخ
مسخ
مسد
مسد
مسر
مسط
مسك
مسك
مسك
مسل
مسن
مسى
مسى
مش
مشج
مشح
مشر
مشر
مشط
مشط
مشط
مشط
مشظ
مشظ
مشع
مشغ
مشق
مشق
مشل
مشن
مشى
مشى
مص
مص
مصت
مصح
مصح
مصخ
مصد
مصر
مصر
مصط
مصع
مصل
مصمص
مض
مض
مض
مضا
مضح
مضر
مضر
مضض
مضغ
مضغ
مضمض
مضى
مضى
مط
مطأ
مطح
مطخ
مطر
مطر
مطس
مطط
مطع
مطل
مطه
مظ
مظع
مع
معا
معت
معج
معجم
معد
معد
معد
معدن
معر
معز
معز
معس
معص
معض
معط
معط
معق
معق
معك
معك
معك
معل
معن
معن
معن
مغا
مغث
مغد
مغد
مغر
مغرب
مغس
مغص
مغط
مغط
مغط
مغل
مغل
مغل
مغمغ
مغنط
مغى
مفصل
مق
مق
مقا
مقت
مقت
مقر
مقر
مقس
مقس
مقط
مقط
مقع
مقل
مقمق
مقه
مقى
مك
مكا
مكت
مكث
مكث
مكد
مكر
مكر
مكر
مكس
مكك
مكل
مكن
مكن
مكن
مكنن
مكي
مل
مل
ملأ
ملؤ
ملئ
ملا
ملث
ملج
ملج
ملح
ملح
ملح
ملح
ملح
ملخ
ملخ
ملد
ملد
ملذ
ملذ
ملز
ملس
ملس
ملس
ملس
ملش
ملص
ملص
ملط
ملط
ملط
ملع
ملق
ملق
ملق
ملك
ملك
ململ
منأ
منا
منح
منح
منطق
منع
منع
منع
منن
منى
منى
مه
مه
مها
مهج
مهد
مهد
مهر
مهر
مهر
مهر
مهز
مهق
مهك
مهك
مهل
مهن
مهن
مهن
مهو
مهى
موت
موضع
مول
مول
مون
موه
موه
ميز
ميع
ميل
ميل
نأت
نأث
نأج
نأد
نأر
نأش
نأف
نأل
نأم
نأم
نأى
نئف
ناء
ناءى
ناب
ناب
نابذ
نابل
نات
نات
ناج
ناجد
ناجز
ناجى
ناح
ناحر
ناد
نادم
نادى
نار
نار
نازع
نازل
ناس
ناسب
ناسخ
ناسق
ناسم
ناش
ناشب
ناشد
ناص
ناص
ناصب
ناصح
ناصر
ناصف
ناض
ناضح
ناضل
ناط
ناط
ناطح
ناطق
ناظر
ناع
ناع
ناعم
ناغم
ناغى
ناف
نافث
نافح
نافد
نافذ
نافر
نافس
نافق
نافى
ناق
ناقب
ناقد
ناقر
ناقس
ناقش
ناقض
ناقل
ناك
ناكح
ناكد
نال
نال
نال
نال
نامس
ناه
ناهب
ناهد
ناهز
ناهض
ناوأ
ناوب
ناور
ناوش
ناول
نب
نبأ
نبأ
نبا
نبب
نبت
نبت
نبت
نبث
نبج
نبج
نبج
نبج
نبخ
نبذ
نبذ
نبذ
نبر
نبز
نبس
نبش
نبص
نبط
نبط
نبع
نبع
نبع
نبغ
نبغ
نبغ
نبق
نبك
نبل
نبل
نبه
نبه
نبه
نبه
نتأ
نتا
نتج
نتخ
نتر
نتر
نتس
نتش
نتض
نتع
نتع
نتغ
نتغ
نتف
نتف
نتق
نتق
نتك
نتل
نتل
نتن
نتن
نتن
نتن
نث
نث
نثا
نثج
نثر
نثر
نثط
نثل
نثل
نثم
نثى
نج
نجأ
نجا
نجا
نجب
نجب
نجب
نجث
نجح
نجح
نجخ
نجد
نجد
نجد
نجد
نجد
نجذ
نجر
نجر
نجز
نجز
نجز
نجس
نجس
نجس
نجش
نجع
نجع
نجع
نجع
نجف
نجف
نجل
نجل
نجم
نجم
نجه
نجى
نح
نحا
نحا
نحب
نحب
نحب
نحب
نحب
نحب
نحب
نحب
نحب
نحت
نحت
نحت
نحت
نحر
نحز
نحز
نحز
نحس
نحس
نحس
نحس
نحص
نحض
نحض
نحض
نحط
نحف
نحف
نحل
نحل
نحل
نحل
نحل
نحل
نحم
نحم
نحنح
نحى
نحى
نحى
نخ
نخا
نخب
نخب
نخب
نخج
نخر
نخر
نخر
نخر
نخر
نخر
نخز
نخس
نخس
نخش
نخش
نخش
نخص
نخص
نخص
نخع
نخع
نخف
نخف
نخل
نخل
نخم
نخم
ند
ندأ
ندا
ندب
ندب
ندب
ندح
ندخ
ندد
ندر
ندر
ندس
ندس
ندش
ندص
ندص
ندغ
ندف
ندف
ندل
ندل
ندم
نده
ندى
نذ
نذخ
نذر
نذر
نذر
نذع
نذل
نز
نزأ
نزا
نزب
نزج
نزح
نزح
نزر
نزر
نزر
نزع
نزع
نزع
نزغ
نزغ
نزف
نزف
نزف
نزق
نزك
نزل
نزل
نزل
نزه
نزه
نزه
نزه
نس
نس
نسأ
نسا
نسب
نسب
نسج
نسج
نسح
نسح
نسخ
نسر
نسر
نسع
نسغ
نسف
نسف
نسق
نسق
نسك
نسك
نسل
نسل
نسم
نسى
نسى
نسي
نش
نش
نشأ
نشأ
نشؤ
نشب
نشب
نشج
نشح
نشد
نشد
نشر
نشر
نشر
نشر
نشر
نشر
نشص
نشص
نشط
نشط
نشط
نشط
نشع
نشغ
نشف
نشف
نشف
نشف
نشق
نشل
نشل
نشم
نشم
نشي
نص
نص
نصا
نصب
نصب
نصب
نصب
نصت
نصح
نصح
نصر
نصر
نصص
نصع
نصف
نصف
نصل
نض
نضا
نضب
نضج
نضج
نضح
نضح
نضخ
نضخ
نضد
نضد
نضر
نضر
نضر
نضف
نضف
نضف
نضل
نضل
نضى
نضى
نط
نطا
نطب
نطح
نطح
نطر
نطس
نطع
نطف
نطف
نطف
نطف
نطق
نطق
نطق
نطل
نطل
نظر
نظر
نظف
نظف
نظم
نظم
نع
نعا
نعب
نعب
نعت
نعت
نعت
نعث
نعج
نعج
نعر
نعر
نعس
نعس
نعش
نعش
نعص
نعض
نعظ
نعق
نعق
نعل
نعل
نعم
نعم
نعنع
نعى
نغب
نغب
نغب
نغت
نغر
نغز
نغش
نغص
نغص
نغص
نغض
نغض
نغف
نغق
نغق
نغل
نغل
نغم
نغى
نف
نف
نفت
نفث
نفث
نفج
نفج
نفح
نفخ
نفخ
نفخ
نفد
نفد
نفذ
نفذ
نفذ
نفر
نفر
نفر
نفز
نفس
نفس
نفس
نفس
نفش
نفش
نفش
نفش
نفص
نفض
نفض
نفط
نفط
نفع
نفع
نفغ
نفغ
نفق
نفق
نفق
نفق
نفل
نفل
نفه
نفه
نفى
نق
نقا
نقب
نقب
نقب
نقب
نقث
نقح
نقح
نقخ
نقد
نقد
نقذ
نقذ
نقر
نقر
نقر
نقز
نقز
نقس
نقس
نقس
نقس
نقش
نقش
نقص
نقص
نقص
نقض
نقض
نقط
نقط
نقع
نقع
نقع
نقف
نقل
نقل
نقل
نقم
نقم
نقم
نقنق
نقه
نقه
نقى
نقى
نقي
نكأ
نكب
نكب
نكب
نكب
نكت
نكت
نكث
نكث
نكح
نكح
نكخ
نكد
نكد
نكد
نكر
نكر
نكر
نكز
نكز
نكس
نكس
نكش
نكش
نكص
نكص
نكص
نكظ
نكظ
نكع
نكع
نكف
نكف
نكف
نكل
نكل
نكل
نكل
نكه
نكه
نكى
نكي
نم
نم
نمر
نمر
نمر
نمس
نمس
نمس
نمش
نمش
نمش
نمص
نمص
نمط
نمق
نمق
نمل
نمل
نمنم
نمه
نمى
نمى
نهأ
نهؤ
نهئ
نهب
نهب
نهب
نهت
نهج
نهج
نهج
نهد
نهد
نهد
نهر
نهر
نهز
نهس
نهس
نهش
نهش
نهض
نهط
نهف
نهق
نهق
نهق
نهق
نهك
نهك
نهك
نهل
نهم
نهم
نهم
نهو
نهى
نهى
نهي
نوب
نور
نورج
نوس
نوع
نوق
نوق
نوك
نول
نول
نوم
نون
نوه
نوه
نوى
نوى
نيب
نيح
نير
نيف
نيل
نيه
هاء
هاء
هاب
هاب
هاتر
هاث
هاج
هاجر
هاجس
هاجم
هاجى
هاد
هاد
هادن
هادى
هاذب
هار
هازل
هاس
هاس
هاص
هاض
هاط
هاع
هاع
هاف
هال
هال
هال
هام
هامر
هامس
هان
هان
هاود
هاوش
هاون
هايج
هايط
هب
هب
هبا
هبب
هبت
هبث
هبج
هبج
هبد
هبذ
هبر
هبر
هبز
هبش
هبش
هبش
هبص
هبص
هبط
هبط
هبع
هبع
هبغ
هبل
هبل
هبل
هبهب
هت
هتأ
هتئ
هتا
هتر
هتر
هتش
هتع
هتف
هتك
هتك
هتل
هتم
هتم
هتن
هث
هثم
هثى
هج
هج
هجأ
هجئ
هجا
هجب
هجج
هجد
هجد
هجر
هجر
هجس
هجش
هجع
هجع
هجف
هجف
هجف
هجل
هجم
هجم
هجم
هجن
هجن
هجن
هجن
هجو
هجى
هجي
هد
هد
هد
هدأ
هدئ
هدب
هدب
هدب
هدج
هدج
هدج
هدد
هدر
هدر
هدر
هدغ
هدف
هدف
هدك
هدل
هدل
هدم
هدم
هدم
هدن
هدن
هدهد
هدى
هدى
هذ
هذأ
هذئ
هذا
هذب
هذب
هذر
هذر
هذر
هذف
هذم
هذى
هر
هر
هر
هر
هر
هر
هرأ
هرأ
هرئ
هرا
هرب
هرب
هرب
هرت
هرت
هرت
هرج
هرج
هرج
هرج
هرد
هرد
هرد
هرز
هرس
هرس
هرس
هرش
هرش
هرش
هرش
هرص
هرض
هرط
هرط
هرطق
هرع
هرع
هرف
هرف
هرق
هرق
هرم
هرم
هرم
هرهر
هرول
هرى
هز
هز
هزأ
هزا
هزبر
هزج
هزج
هزر
هزز
هزع
هزع
هزف
هزق
هزل
هزل
هزل
هزل
هزم
هزم
هزهز
هس
هس
هس
هس
هسع
هسهس
هش
هش
هش
هش
هش
هش
هش
هشر
هشم
هشم
هشهش
هص
هص
هصا
هصر
هصر
هصم
هض
هضب
هضل
هضم
هضم
هطا
هطر
هطع
هطف
هف
هفا
هفت
هفك
هفك
هفهف
هق
هقع
هقع
هقف
هقم
هقى
هك
هكب
هكر
هكر
هكع
هكع
هل
هلب
هلب
هلت
هلج
هلد
هلس
هلع
هلك
هلك
هلل
هلم
هلهل
هم
هم
هم
هم
هم
هم
همأ
همت
همد
همد
همد
همذ
همر
همر
همز
همس
همش
همش
همش
همش
همط
همع
همغ
همك
همل
همل
همل
همل
همم
همهم
هن
هنأ
هنأ
هنأ
هنؤ
هنب
هند
هند
هندس
هندم
هنع
هنع
هنغ
هنق
هوئ
هوج
هود
هور
هوز
هوس
هوس
هوش
هوش
هوع
هوك
هول
هوم
هون
هوى
هوي
هيأ
هيب
هيب
هيج
هيع
هيغ
هيف
هيف
هيكل
هيل
هيلل
هيم
هيمن
وأب
وأب
وأد
وأص
وأط
وأم
وأوأ
وأى
وئب
واءم
وابل
واتر
واثب
واثق
واجب
واجل
واجه
واحل
واخم
واد
وادع
وارب
وارد
وارع
وارق
وارى
وازر
وازن
وازى
واسق
واسم
واسى
واشك
واصب
واصل
واضأ
واطأ
واطن
واظب
واظف
واعد
واغد
وافد
وافق
وافى
واقع
واقف
واكأ
واكب
واكف
واكل
والف
والى
وامق
واهب
وبأ
وبؤ
وبئ
وبخ
وبد
وبر
وبش
وبش
وبص
وبص
وبط
وبط
وبط
وبغ
وبق
وبق
وبق
وبق
وبق
وبل
وبل
وبه
وبه
وتأ
وتب
وتح
وتح
وتخ
وتد
وتد
وتر
وتر
وتغ
وتم
وتن
وثأ
وثئ
وثب
وثب
وثج
وثر
وثر
وثر
وثغ
وثف
وثف
وثق
وثق
وثل
وثل
وثم
وثم
وثم
وثن
وج
وجأ
وجب
وجب
وجب
وجح
وجح
وجد
وجد
وجر
وجر
وجز
وجز
وجس
وجع
وجع
وجف
وجل
وجل
وجل
وجم
وجن
وجن
وجه
وجه
وجه
وجى
وجي
وحج
وحد
وحد
وحد
وحر
وحر
وحش
وحش
وحص
وحف
وحف
وحف
وحف
وحل
وحل
وحم
وحم
وحن
وحن
وحوح
وحى
وخد
وخز
وخش
وخض
وخط
وخف
وخف
وخم
وخم
وخم
وخم
وخى
وخى
ود
ودأ
ودئ
ودج
ودج
ودر
ودس
ودع
ودع
ودع
ودع
ودق
ودق
ودك
ودك
ودل
ودن
ودن
ودن
ودن
وده
ودى
وذأ
وذح
وذر
وذر
وذع
وذف
وذم
وذم
وذى
ورأ
ورب
ورب
ورث
ورث
ورخ
ورد
ورد
ورد
ورذ
ورس
ورس
ورس
ورش
ورش
ورش
ورص
ورض
ورط
ورع
ورع
ورع
ورع
ورع
ورف
ورف
ورق
ورق
ورك
ورك
ورك
ورك
ورم
ورم
وره
وره
وره
وره
ورور
ورى
وري
وري
وري
وري
وزأ
وزب
وزر
وزر
وزر
وزع
وزع
وزع
وزغ
وزف
وزف
وزم
وزن
وزن
وزن
وزوز
وزى
وسب
وسب
وسج
وسخ
وسخ
وسد
وسط
وسط
وسط
وسط
وسط
وسع
وسع
وسع
وسع
وسق
وسق
وسق
وسل
وسل
وسم
وسم
وسم
وسن
وسوس
وسى
وشج
وشج
وشح
وشر
وشظ
وشع
وشغ
وشق
وشق
وشق
وشك
وشل
وشم
وشم
وشوش
وشى
وشى
وصئ
وصب
وصب
وصد
وصد
وصع
وصف
وصف
وصل
وصل
وصل
وصم
وصم
وصوص
وصى
وصى
وضأ
وضأ
وضؤ
وضب
وضح
وضح
وضح
وضخ
وضر
وضع
وضع
وضع
وضع
وضع
وضع
وضف
وضم
وضن
وط
وطأ
وطأ
وطؤ
وطئ
وطح
وطد
وطد
وطس
وطش
وطف
وطف
وطم
وطم
وطن
وطن
وطوط
وظب
وظب
وظف
وظف
وعب
وعث
وعث
وعد
وعد
وعر
وعر
وعر
وعر
وعز
وعس
وعظ
وعف
وعق
وعق
وعق
وعك
وعك
وعل
وعم
وعوع
وعى
وعى
وغب
وغد
وغر
وغر
وغر
وغف
وغم
وغم
وفد
وفد
وفر
وفر
وفر
وفز
وفض
وفق
وفل
وفه
وفى
وفى
وفى
وقب
وقت
وقت
وقح
وقح
وقح
وقح
وقد
وقذ
وقر
وقر
وقر
وقر
وقس
وقش
وقص
وقص
وقط
وقظ
وقع
وقع
وقف
وقف
وقل
وقم
وقه
وقوق
وقى
وقى
وكب
وكب
وكب
وكت
وكح
وكد
وكد
وكر
وكر
وكز
وكس
وكظ
وكع
وكع
وكع
وكف
وكف
وكف
وكل
وكل
وكم
وكم
وكن
وكى
ولت
ولث
ولج
ولج
ولح
ولخ
ولد
ولد
ولذ
ولس
ولع
ولع
ولغ
ولغ
ولغ
ولغ
ولف
ولق
وله
وله
وله
وله
ولول
ولى
ولى
ولي
ولي
ومأ
ومأ
ومد
ومز
ومس
ومض
ومق
ومه
ونك
ونم
ونى
ونى
وني
وهب
وهت
وهث
وهج
وهد
وهر
وهز
وهس
وهص
وهط
وهف
وهف
وهق
وهل
وهل
وهل
وهل
وهم
وهم
وهم
وهن
وهن
وهن
وهوه
وهى
وهي
ويل
يأس
يئس
ياسر
يامن
ياوم
يبب
يبس
يبس
يبس
يتم
يتم
يتم
يتم
يتن
يدى
يدي
ير
يرع
يس
يسر
يسر
يسر
يسر
يعر
يعر
يفخ
يفع
يق
يقظ
يقظ
يقظ
يقن
يل
يل
يمم
يمن
يمن
يمن
ينع
يهم
""".split('\n')

# stampall verbs
VERB_LIST = [verb_stamp(x) for x in VERB_LIST]
# use it as a set
VERB_LIST = set(VERB_LIST)
if __name__ == "__main__":
    from pyarabic.arabrepr import arepr as repr
    print("set verb list ", len(VERB_LIST))
    print(repr(VERB_LIST))

